(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    136304,       3944]
NotebookOptionsPosition[    117144,       3643]
NotebookOutlinePosition[    117589,       3661]
CellTagsIndexPosition[    117546,       3658]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Insurance Model\n", "Subtitle"],
 StyleBox["The first-best benchmark", "Section"]
}], "Chapter",
 CellChangeTimes->{{3.846994013564211*^9, 3.8469940156856823`*^9}, {
  3.846994857600985*^9, 3.846994859748948*^9}, {3.846994896420465*^9, 
  3.8469949852663383`*^9}},ExpressionUUID->"a39687ae-fc3b-4bb9-bd7f-\
6a1cce55c6bd"],

Cell["\<\
By analyzing a centralized controlled supply chain. Without the need to \
consider payment to the vehicle manufacture and deal with insurancing within \
a centralized, controlled system, the expected savings associated with \
launching vie an internal spacecraft are equal to\
\>", "Text",
 CellChangeTimes->{
  3.847072295759438*^9},ExpressionUUID->"4a074443-24c5-409e-83aa-\
d5efd512c40f"],

Cell[BoxData[
 RowBox[{"Profitv", ":=", 
  RowBox[{
   RowBox[{"\[Alpha]", " ", "p"}], "+", 
   RowBox[{"e", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], "\[Theta]"}], "-", 
   RowBox[{"k", "*", 
    RowBox[{"(", 
     RowBox[{"e", "*", "e"}], ")"}]}], "-", "cv"}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"b97db057-3326-4570-b145-bf5f3b37db78"],

Cell[BoxData[
 RowBox[{"Profits", ":=", 
  RowBox[{"v", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", "p"}], "+", 
     RowBox[{"e", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "+", "cs"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.847072365050516*^9, 3.8470723873118153`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"79cfa81a-e7be-48c4-a2d1-ac54021f07e2"],

Cell[BoxData[
 RowBox[{"Profitc", ":=", 
  RowBox[{"Profits", "+", "Profitv"}]}]], "Input",
 CellChangeTimes->{{3.847072289480255*^9, 3.847072312746649*^9}, {
  3.847072429685445*^9, 3.847072436130612*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"53785147-afaf-421b-9557-079ea54a50de"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"Profitc", ",", "e"}], "]"}]], "Input",
 CellChangeTimes->{{3.847072439483007*^9, 
  3.847072474565583*^9}},ExpressionUUID->"e5ce236c-099f-4fa3-baeb-\
556f27ae00e1"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", "e", " ", "k"}], "+", "\[Theta]"}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{3.847072496013612*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"36a6f063-e7cb-456b-a8fa-26f7686dc301"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", "e"}], "]"}]], "Input",
 CellChangeTimes->{{3.847072505694669*^9, 3.8470725139318657`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"9535aaaa-7402-46ed-a57c-598d9755fb32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    FractionBox["\[Theta]", 
     RowBox[{"2", " ", "k"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.847072514258151*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"e7dd1525-589b-464a-84dc-f91157728724"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"e", ":=", 
   FractionBox["\[Theta]", 
    RowBox[{"2", " ", "k"}]]}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{{3.847072518589052*^9, 3.847072526636067*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"a6b4c8f3-f4b1-4542-b04d-0c61fa353d55"],

Cell[BoxData["Profitc"], "Input",
 CellChangeTimes->{{3.84707255448181*^9, 3.8470725558618927`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"3d692f04-76cd-4929-b634-5612de74c716"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", "c"], "=", " ", 
   RowBox[{
    RowBox[{"-", "cs"}], "-", "cv", "-", 
    RowBox[{
     SuperscriptBox["e", "2"], " ", "k"}], "+", "v", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "e"}], ")"}], " ", "\[Theta]"}]}]}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{{3.847145356327112*^9, 
  3.847145370756509*^9}},ExpressionUUID->"a1c40ca2-1b2e-42b9-a8ad-\
ea757e0a057d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "-", "cv", "+", "v", "-", 
   FractionBox[
    SuperscriptBox["\[Theta]", "2"], 
    RowBox[{"4", " ", "k"}]], "-", 
   RowBox[{"\[Theta]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Theta]", 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[9]:=",ExpressionUUID->"6bfe07aa-d077-4fee-8be6-e182ce2d877c"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"-", "cs"}], "-", "cv", "+", "v", "-", "\[Theta]", "+", 
   FractionBox[
    SuperscriptBox["\[Theta]", "2"], 
    RowBox[{"4", " ", "k"}]]}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{3.8470725701697483`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"a0a114d9-6e19-44aa-8b58-739f998a2b1b"],

Cell[CellGroupData[{

Cell[TextData[{
 "Lemma 1\n",
 StyleBox["In a centralized chain, the satellite owner contract with the \
vehicle manufacture if and only if ", "Text",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"v", "+", 
    FractionBox[
     SuperscriptBox["\[Theta]", "2"], 
     RowBox[{"4", " ", "k"}]]}],
   FontColor->RGBColor[1, 0, 0]]], "Input",
  CellChangeTimes->{3.8470725701697483`*^9},ExpressionUUID->
  "d3a2c6ce-a42c-47c4-b6f8-82821059b1f6"],
 StyleBox[" ", "Text",
  FontColor->GrayLevel[0]],
 StyleBox["\[GreaterEqual] cs + cv + \[Theta]  ", "Text",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[". The resulting launch probability is ", "Text",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FractionBox["\[Theta]", 
   RowBox[{"2", " ", "k"}]]],
  CellChangeTimes->{{3.847072518589052*^9, 3.847072526636067*^9}},
  ExpressionUUID->"5afc9f15-b5f3-447e-9c4f-0a4071729f20"],
 StyleBox[", and the corresponding chain payoff is ", "Text",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{"-", "cs"}], "-", "cv", "+", "v", "-", "\[Theta]", "+", 
    FractionBox[
     SuperscriptBox["\[Theta]", "2"], 
     RowBox[{"4", " ", "k"}]]}],
   FontColor->RGBColor[1, 0, 0]]], "Input",
  CellChangeTimes->{3.8470725701697483`*^9},ExpressionUUID->
  "aefd4a2d-0017-4666-a46a-e0c85972db57"],
 StyleBox[".\n\nIt follows from the lemma1  that, in order to avoid trivial \
cases, we assume that ", "Text",
  FontColor->GrayLevel[0]],
 StyleBox["k >\[Theta]/2 ", "Text",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["and ", "Text",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"v", "+", 
    FractionBox[
     SuperscriptBox["\[Theta]", "2"], 
     RowBox[{"4", " ", "k"}]], "-", "cv", "-", "\[Theta]"}],
   FontColor->RGBColor[1, 0, 0]]], "Input",
  CellChangeTimes->{3.8470725701697483`*^9},ExpressionUUID->
  "6a18bb1d-d9d9-4604-af77-ae0a23ae8065"],
 StyleBox[" ", "Text",
  FontColor->GrayLevel[0]],
 StyleBox["\[GreaterEqual]cs ", "Text",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["throughout this paper. ", "Text",
  FontColor->GrayLevel[0]]
}], "Section",
 CellChangeTimes->{{3.847072621464958*^9, 3.847072634540354*^9}, {
  3.847072726456894*^9, 3.8470727475798388`*^9}, {3.847072805201377*^9, 
  3.847072843567854*^9}, {3.8470729113579206`*^9, 3.847073031006254*^9}, {
  3.8470731528824472`*^9, 3.847073179144915*^9}, {3.8470733324003267`*^9, 
  3.847073344605122*^9}, {3.847073375844777*^9, 3.847073377406995*^9}, {
  3.847073424844791*^9, 3.847073505663547*^9}, {3.847073555664248*^9, 
  3.847073568298669*^9}, {3.8470736020073853`*^9, 3.84707365478864*^9}, {
  3.847073685776712*^9, 3.847073765658246*^9}, {3.847073908138644*^9, 
  3.847073909550741*^9}, {3.847145461780875*^9, 3.847145546076703*^9}, {
  3.8471458813531313`*^9, 
  3.8471459088602533`*^9}},ExpressionUUID->"fe88380d-793a-4f5f-b64c-\
83e0a6b818d6"],

Cell[CellGroupData[{

Cell[TextData[{
 "Assumption 1\n",
 StyleBox["The vehicle manufacture\[CloseCurlyQuote]s cost cv and his failure \
penalty level a satisfy", "Text",
  FontColor->GrayLevel[0]],
 StyleBox[" 0 \[LessEqual] \[Theta] \[LessEqual] cv \[LessEqual]", "Text",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" ", "Text",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"v", "+", 
    FractionBox[
     SuperscriptBox["\[Theta]", "2"], 
     RowBox[{"4", " ", "k"}]], "-", "cs", "-", "\[Theta]"}],
   FontColor->RGBColor[1, 0, 0]]],
  CellChangeTimes->{3.8470725701697483`*^9},ExpressionUUID->
  "0cd69792-f05a-4922-bf79-1d94e32d56b2"],
 StyleBox[".", "Text",
  FontColor->GrayLevel[0]]
}], "Subsection",
 CellChangeTimes->{{3.847073093195812*^9, 3.8470731037456017`*^9}, {
  3.847073796283391*^9, 3.8470738544159527`*^9}, {3.8470739117702103`*^9, 
  3.847073933193*^9}},ExpressionUUID->"6a672dce-496a-4be8-9aaa-aeac76186792"],

Cell["", "Outline5",
 CellChangeTimes->{
  3.847072706267499*^9},ExpressionUUID->"faa6d505-3217-48b9-8ae3-\
0b4087d78c0a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The VM\[CloseCurlyQuote]s Effort Under Insurance Model", "Section",
 CellChangeTimes->{{3.8470724126182137`*^9, 3.847072424750353*^9}, {
  3.8470751753004932`*^9, 
  3.8470751937801857`*^9}},ExpressionUUID->"d1c34096-ed56-4bf5-8295-\
cf32091bad59"],

Cell[BoxData[{
 RowBox[{"Profitv", ":=", 
  RowBox[{
   RowBox[{"\[Alpha]", " ", "p"}], "+", 
   RowBox[{"e", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], "\[Theta]"}], "-", 
   RowBox[{"k", "*", 
    RowBox[{"(", 
     RowBox[{"e", "*", "e"}], ")"}]}], "-", "cv"}]}], "\[IndentingNewLine]", 
 RowBox[{"Profits", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[Alpha]"}], " ", "p"}], "+", 
   RowBox[{"e", 
    RowBox[{"(", 
     RowBox[{"f", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}]}], ")"}]}], "-", "cs", 
   " ", "-", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs", "+", "f"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs", "+", "f"}], 
     ")"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.846994998245145*^9, 3.8469950417569017`*^9}, {
  3.8469951304226103`*^9, 3.846995258470537*^9}, {3.84699543311882*^9, 
  3.84699545867137*^9}, {3.846995492307365*^9, 3.846995496643367*^9}, {
  3.847071574315486*^9, 3.847071676196108*^9}, {3.8470717178586597`*^9, 
  3.847071728403867*^9}, {3.847101586691174*^9, 3.8471015994164743`*^9}, {
  3.847326020480481*^9, 3.8473260725167913`*^9}, {3.8473261505798407`*^9, 
  3.847326161336322*^9}, {3.847326488652102*^9, 
  3.847326489366748*^9}},ExpressionUUID->"8a5e1f21-e832-4717-962f-\
486d55afa183"],

Cell[BoxData[
 RowBox[{"Profiti", ":=", 
  RowBox[{
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8470765697005787`*^9, 3.847076577232677*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"8cbb3264-6d58-415e-92c3-60128108ea58"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"\[IndentingNewLine]", 
   RowBox[{"D", "[", 
    RowBox[{"Profitv", ",", "e"}], "]"}]}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{
  3.846995334466803*^9, {3.8470719931159678`*^9, 3.847072003950798*^9}, {
   3.847074019138771*^9, 3.847074025716756*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"d31efafa-2322-4f06-9ec0-e5237b333828"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "e", " ", "k"}], "+", 
  RowBox[{"p", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "+", "\[Theta]"}]], "Output",
 CellChangeTimes->{3.847072004716967*^9, 3.8470740274973583`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"044ffb70-ef1f-4f88-9328-646880c8f795"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", "e"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.847072017401827*^9, 3.8470720216663227`*^9}, {
   3.847072058176536*^9, 3.847072063332715*^9}, 3.847074034630993*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"de76a8b0-490e-424c-b61a-95614f7fe848"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    FractionBox[
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"2", " ", "k"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.847072063806499*^9, 3.8470740371454697`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"67d1a863-98af-414a-861a-eb34be153095"]
}, Open  ]],

Cell["\<\
We now solve the Stackelberg game  by using backward induction. First, given \
any contingent price p , by considering the first-order condition of Profitv, \
the vehicle manufacture\[CloseCurlyQuote]s best response is given as\
\>", "Text",
 CellChangeTimes->{
  3.847074658894882*^9},ExpressionUUID->"451b9fe5-3c3d-4613-908c-\
73909ca7437c"],

Cell[BoxData[{
 StyleBox[
  RowBox[{"e", ":=", 
   FractionBox[
    RowBox[{"p", "-", 
     RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
    RowBox[{"2", " ", "k"}]]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"r", ":=", 
   RowBox[{"1", "-", "e"}]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]"
 StyleBox[,
  FontColor->RGBColor[1, 0, 0]]}], "Input",
 CellChangeTimes->{{3.847072090450409*^9, 3.847072097890996*^9}, {
  3.847074047134727*^9, 3.847074085951888*^9}, {3.847326091109666*^9, 
  3.84732609837551*^9}, {3.8473262599652023`*^9, 
  3.8473262725364037`*^9}},ExpressionUUID->"c1c41658-3282-4887-9481-\
14e609cd0c24"],

Cell[CellGroupData[{

Cell[BoxData["r"], "Input",
 CellChangeTimes->{3.847326265641618*^9},
 CellLabel->"In[50]:=",ExpressionUUID->"25cb81c3-86cf-4008-824c-618161218f24"],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{"p", "-", 
    RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.8473262660577917`*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"260ac273-416b-444b-a3de-a810a1416a8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Profits"], "Input",
 CellChangeTimes->{{3.847326278565195*^9, 3.847326280621648*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"8be2c682-3e94-4521-ab90-197cf842636c"],

Cell[BoxData[
 RowBox[{"cs", "-", 
  RowBox[{"p", " ", "\[Alpha]"}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"f", "-", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.847326282378286*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"db458e3f-3cc9-48d2-bc7d-8bae9c67660b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"cs", "-", 
   RowBox[{"p", " ", "\[Alpha]"}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"f", "-", 
       RowBox[{"p", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[52]:=",ExpressionUUID->"cf5a4bec-fb6e-4eb0-a1a2-1252486ce01f"],

Cell[BoxData[
 RowBox[{"cs", "-", 
  RowBox[{"p", " ", "\[Alpha]"}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"f", "+", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.847326284374515*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"ba5276aa-c895-415e-a3e2-47271b67f117"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.847326110036812*^9, 3.84732611402052*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"6543476a-4e42-4bfc-a9f1-07581f0ccaf9"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"f", "+", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "-", "\[Alpha]", "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.847326114600947*^9, 3.8473261842117662`*^9, 
  3.847326291721788*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"92dae79e-61cb-4485-8b70-00b47c02decf"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.847326116756496*^9, 3.847326123545939*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"55edf4ba-a82b-4d55-94a0-8ebbc3d8113a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", 
    StyleBox["\[Rule]",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     FractionBox[
      RowBox[{"f", "-", 
       RowBox[{"f", " ", "\[Alpha]"}], "-", 
       RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
       RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}]],
     FontColor->RGBColor[1, 0, 0]]}], "}"}], "}"}]], "Input",
 CellChangeTimes->{3.847326319213255*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"fa7a84f4-163d-4a38-81e7-8a1525d77575"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.847326248990149*^9, 
  3.84732625476409*^9}},ExpressionUUID->"d95483e2-77aa-49c6-b85a-\
99d4c84674e9"],

Cell[CellGroupData[{

Cell[BoxData["Profitv"], "Input",
 CellChangeTimes->{{3.846995260592287*^9, 3.846995260593275*^9}, {
  3.847074094554541*^9, 3.847074097041191*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"434a0535-7d04-4d53-b2de-8417db3361f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cv"}], "+", 
  RowBox[{"p", " ", "\[Alpha]"}], "+", 
  FractionBox[
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "-", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}], "2"], 
   RowBox[{"4", " ", "k"}]], "-", 
  RowBox[{"\[Theta]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.84707409886814*^9, 3.84732600565388*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"b7776507-15f1-4b45-8d7c-33844b26640e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cv"}], "+", 
   RowBox[{"p", " ", "\[Alpha]"}], "+", 
   FractionBox[
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}], "2"], 
    RowBox[{"4", " ", "k"}]], "-", 
   RowBox[{"\[Theta]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[32]:=",ExpressionUUID->"840dcf7e-69db-43fc-9142-46360f97dd28"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", "cv", " ", "k"}], "+", 
   RowBox[{
    SuperscriptBox["p", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "+", 
   RowBox[{"\[Theta]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "k"}], "+", "\[Theta]"}], ")"}]}], "+", 
   RowBox[{"2", " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", "\[Theta]", "-", 
      RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], ")"}]}]}], 
  RowBox[{"4", " ", "k"}]]], "Output",
 CellChangeTimes->{3.847326009308363*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"6ae48cb6-a000-4427-8300-d7724c871c89"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cv"}], "+", 
   RowBox[{"p", " ", "\[Alpha]"}], "+", 
   FractionBox[
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}], "2"], 
    RowBox[{"4", " ", "k"}]], "-", 
   RowBox[{"\[Theta]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[10]:=",ExpressionUUID->"d773155c-a29b-47d0-9c22-dbcca16e2801"],

Cell["\<\
By substituting e into the vehicle manufacture\[CloseCurlyQuote]s payoff \
Profitv  it is easy to check that\
\>", "Text",
 CellChangeTimes->{{3.847074681284581*^9, 
  3.8470747098134003`*^9}},ExpressionUUID->"50bc3183-f931-4469-a255-\
541f34284653"],

Cell[BoxData[
 StyleBox[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", "cv", " ", "k"}], "+", 
    RowBox[{
     SuperscriptBox["p", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "+", 
    RowBox[{"\[Theta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "k"}], "+", "\[Theta]"}], ")"}]}], "+", 
    RowBox[{"2", " ", "p", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", "\[Theta]", "-", 
       RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], ")"}]}]}], 
   RowBox[{"4", " ", "k"}]],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{3.847074116982687*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"203e64c2-90ab-4789-97d1-516b527fe727"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.846995238517687*^9, 3.846995238519948*^9}, {
  3.847074121838304*^9, 3.847074127692197*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"f5e832c2-d924-4517-ad74-e1c0f8b68538"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
       RowBox[{"\[Alpha]", " ", "\[Theta]"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"cv", " ", "k"}], "-", 
          RowBox[{"2", " ", "cv", " ", "k", " ", "\[Alpha]"}], "+", 
          RowBox[{"cv", " ", "k", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"k", " ", "\[Theta]"}], "-", 
          RowBox[{"k", " ", "\[Alpha]", " ", "\[Theta]"}]}]]}]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "\[Alpha]"}], "+", 
       SuperscriptBox["\[Alpha]", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
       RowBox[{"\[Alpha]", " ", "\[Theta]"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"cv", " ", "k"}], "-", 
          RowBox[{"2", " ", "cv", " ", "k", " ", "\[Alpha]"}], "+", 
          RowBox[{"cv", " ", "k", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"k", " ", "\[Theta]"}], "-", 
          RowBox[{"k", " ", "\[Alpha]", " ", "\[Theta]"}]}]]}]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "\[Alpha]"}], "+", 
       SuperscriptBox["\[Alpha]", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.847074129270467*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"d65b8b64-cd53-4e89-a162-2a26260045a2"]
}, Open  ]],

Cell[TextData[{
 "Hence the vehicle manufacture\[CloseCurlyQuote]s participation condition, \
i.e., Profitv\[GreaterEqual]0, can be written as \np \[GreaterEqual] ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", 
      SqrtBox[
       RowBox[{
        RowBox[{"k", " ", 
         RowBox[{"cv", "\[CenterDot]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]}]}], " ", "+", " ", 
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], 
         SuperscriptBox["k", "2"]}], " ", "+", " ", 
        RowBox[{"\[Theta]", " ", 
         RowBox[{"k", "(", 
          RowBox[{"1", "-", "\[Alpha]"}], ")"}]}]}]]}], " ", "-", 
     RowBox[{"2", "k", " ", "\[Alpha]"}], " ", "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], "\[Theta]"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], TraditionalForm]], 
  "Subsection",ExpressionUUID->"b45ac7a2-6968-4b2b-9313-6cd90281246a"]
}], "Text",
 CellChangeTimes->{{3.847074732349956*^9, 
  3.8470751175043583`*^9}},ExpressionUUID->"7b31a7f5-7396-487c-a8c1-\
0ef980574010"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Profitv", ":=", 
  RowBox[{
   RowBox[{"\[Alpha]", " ", "p"}], "+", 
   RowBox[{"e", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], "\[Theta]"}], "-", 
   RowBox[{"k", "*", 
    RowBox[{"(", 
     RowBox[{"e", "*", "e"}], ")"}]}], "-", "cv"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"Profitv", "\[Equal]", "0"}], ",", "p"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8471066370747643`*^9, 3.84710667255475*^9}, {
  3.8471405088904867`*^9, 
  3.8471405135128117`*^9}},ExpressionUUID->"13b830df-b732-4df8-9ecc-\
2b792bc2a1fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "cv"}], "-", 
      RowBox[{
       SuperscriptBox["e", "2"], " ", "k"}], "-", "\[Theta]", "+", 
      RowBox[{"e", " ", "\[Theta]"}]}], 
     RowBox[{
      RowBox[{"-", "e"}], "-", "\[Alpha]", "+", 
      RowBox[{"e", " ", "\[Alpha]"}]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.847106674999976*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"8fbe1c3a-7feb-4a3b-8935-b5d96f12b240"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"p", ":=", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
    RowBox[{"\[Alpha]", " ", "\[Theta]"}], "+", 
    RowBox[{"2", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"cv", " ", "k"}], "-", 
       RowBox[{"2", " ", "cv", " ", "k", " ", "\[Alpha]"}], "+", 
       RowBox[{"cv", " ", "k", " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "+", 
       RowBox[{"k", " ", "\[Theta]"}], "-", 
       RowBox[{"k", " ", "\[Alpha]", " ", "\[Theta]"}]}]]}]}], 
   RowBox[{"1", "-", 
    RowBox[{"2", " ", "\[Alpha]"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}]]}]], "Input",
 CellChangeTimes->{{3.847313131927696*^9, 3.847313134592923*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"f4d7dc08-b6ac-4a78-a186-6c4093672237"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
       RowBox[{"\[Alpha]", " ", "\[Theta]"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"cv", " ", "k"}], "-", 
          RowBox[{"2", " ", "cv", " ", "k", " ", "\[Alpha]"}], "+", 
          RowBox[{"cv", " ", "k", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"k", " ", "\[Theta]"}], "-", 
          RowBox[{"k", " ", "\[Alpha]", " ", "\[Theta]"}]}]]}]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "\[Alpha]"}], "+", 
       SuperscriptBox["\[Alpha]", "2"]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "k", " ", "e"}], "-", "\[Theta]"}], 
      RowBox[{"1", "-", "\[Alpha]"}]]}], "\[Equal]", "0"}], ",", "e"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.84731317039637*^9, 3.847313216881649*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"d1a517d1-0bad-45c2-aeda-646729bf54ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"k", " ", "\[Alpha]"}], "-", 
      SqrtBox[
       RowBox[{"k", " ", 
        RowBox[{"(", 
         RowBox[{"cv", "-", 
          RowBox[{"2", " ", "cv", " ", "\[Alpha]"}], "+", 
          RowBox[{"cv", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", "\[Theta]", "-", 
          RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], ")"}]}]]}], 
     RowBox[{"k", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8473132184563723`*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"2ccf8f90-6e4e-477d-926d-cca2f48471b4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox["v",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox[":=",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 0]], 
  RowBox[{
   StyleBox["cs",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["+",
    FontColor->RGBColor[1, 0, 0]], "cv", "+", 
   RowBox[{"e", "*", "e", "*", 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["k",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["+",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "e"}], ")"}], " ", "\[Theta]"}],
    FontColor->RGBColor[1, 0, 0]]}]}]], "Input",
 CellChangeTimes->{{3.847316381392889*^9, 3.847316386281818*^9}, {
  3.847316538095078*^9, 3.847316576215047*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"f71c8be6-7a63-4858-b653-06d891d01d27"],

Cell[BoxData[
 StyleBox[
  RowBox[{"e", ":=", 
   FractionBox[
    RowBox[{"p", "-", 
     RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
    RowBox[{"2", " ", "k"}]]}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"57593b88-81c6-46e4-b4f9-c03a1ec8ea14"],

Cell[CellGroupData[{

Cell[BoxData["v"], "Input",
 CellChangeTimes->{{3.847316394580326*^9, 3.847316396268299*^9}, {
  3.847316585719481*^9, 3.847316588737893*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"3d95f9fb-810f-4df0-ac56-28b3fa5dd635"],

Cell[BoxData[
 RowBox[{"cs", "+", "cv", "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}], "2"], 
   RowBox[{"4", " ", "k"}]], "+", 
  RowBox[{"\[Theta]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.847316397599324*^9, 3.84731659002885*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"baa3b0c0-9ec6-480b-a390-cdcfd7a12106"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"cs", "+", "cv", "+", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}], "2"], 
    RowBox[{"4", " ", "k"}]], "+", 
   RowBox[{"\[Theta]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[16]:=",ExpressionUUID->"89b5094a-178e-4af4-bee0-48b3228e2f43"],

Cell[BoxData[
 RowBox[{"cs", "+", "cv", "+", "\[Theta]", "-", 
  FractionBox[
   RowBox[{"\[Theta]", " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}], "2"], 
   RowBox[{"4", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.847316598480695*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"f893fb4a-214c-4263-95fc-f0dc0fa053b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "-", "p"}], "\[Equal]", "0"}], ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.847316417515629*^9, 3.847316424505472*^9}, {
  3.8473167070256987`*^9, 3.847316707808771*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"2fd082ab-2f0d-4dc9-bf82-98ba63309865"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox[
          RowBox[{"1", "-", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"4", " ", "k"}]], "-", 
              FractionBox["\[Alpha]", 
               RowBox[{"2", " ", "k"}]], "+", 
              FractionBox[
               SuperscriptBox["\[Alpha]", "2"], 
               RowBox[{"4", " ", "k"}]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"cs", "+", "cv", "+", "\[Theta]", "-", 
              FractionBox[
               SuperscriptBox["\[Theta]", "2"], 
               RowBox[{"4", " ", "k"}]]}], ")"}]}]}]]}], ")"}]}], 
      RowBox[{
       FractionBox["1", "k"], "-", 
       FractionBox[
        RowBox[{"2", " ", "\[Alpha]"}], "k"], "+", 
       FractionBox[
        SuperscriptBox["\[Alpha]", "2"], "k"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SqrtBox[
          RowBox[{"1", "-", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"4", " ", "k"}]], "-", 
              FractionBox["\[Alpha]", 
               RowBox[{"2", " ", "k"}]], "+", 
              FractionBox[
               SuperscriptBox["\[Alpha]", "2"], 
               RowBox[{"4", " ", "k"}]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"cs", "+", "cv", "+", "\[Theta]", "-", 
              FractionBox[
               SuperscriptBox["\[Theta]", "2"], 
               RowBox[{"4", " ", "k"}]]}], ")"}]}]}]]}], ")"}]}], 
      RowBox[{
       FractionBox["1", "k"], "-", 
       FractionBox[
        RowBox[{"2", " ", "\[Alpha]"}], "k"], "+", 
       FractionBox[
        SuperscriptBox["\[Alpha]", "2"], "k"]}]]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.8473164251941442`*^9, 3.8473167101718073`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"e12a2ad8-c5aa-4408-ba25-77f15a53b394"]
}, Open  ]],

Cell[BoxData[
 FormBox["", TraditionalForm]], "Input",
 CellChangeTimes->{{3.8471404976364803`*^9, 3.847140524197225*^9}, {
  3.847313123915406*^9, 
  3.847313128264559*^9}},ExpressionUUID->"51545df1-71d0-4c26-ab57-\
d1f4faa259d1"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.847106664253661*^9, 
  3.847106664484332*^9}},ExpressionUUID->"aca45777-0963-49b6-8d34-\
30b03810bbab"],

Cell[TextData[StyleBox["The IC\[CloseCurlyQuote]s Premium Rate Under \
Insurance Model", "Section"]], "Text",
 CellChangeTimes->{{3.847075237309936*^9, 
  3.8470752994770823`*^9}},ExpressionUUID->"7f21e962-4957-4667-8436-\
535cdc0b692c"],

Cell[TextData[{
 "Observing the contract price p selected by the satellite owner, the \
insurance company can anticipate the vehicle manufacture\[CloseCurlyQuote]s \
effort e as given above. Operating in a competitive insurance market, the \
insurance company sets its premium rate r to breakeven in expectation. In \
other words, under the premium rate r that it offers, the insurance company\
\[CloseCurlyQuote]s expected profit,",
 StyleBox["r(\[Alpha] p+cs)",
  FontColor->RGBColor[1, 0, 0]],
 ", equals the expected coverage \n",
 StyleBox["(1-e) (\[Alpha] p+cs).",
  FontColor->RGBColor[1, 0, 0]],
 "\nSubstituting e given in",
 Cell[BoxData[
  StyleBox[
   RowBox[{"e", ":=", 
    FractionBox[
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"2", " ", "k"}]]}],
   FontColor->RGBColor[1, 0, 0]]],
  CellChangeTimes->{{3.847072090450409*^9, 3.847072097890996*^9}, {
   3.847074047134727*^9, 3.847074085951888*^9}},ExpressionUUID->
  "892a772e-af24-49c3-b7de-59e02dde3a01"],
 " , the insurance company breakeven condition can be satisfied if and only \
if",
 StyleBox[" p \[GreaterEqual] ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["p", "IA"], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "a04a5a75-2b4a-4546-a878-0a912c642e1e"],
 StyleBox[" \[Congruent]",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", "k", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "r"}], ")"}]}], "-", " ", "\[Theta]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], " "}]]],
  CellChangeTimes->{3.8470757908903217`*^9},
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "63538785-ea7b-4585-80bf-ad153b4a1ce3"],
 " ,which we refer as the ",
 StyleBox["insurance company\[CloseCurlyQuote]s underwriting constraint",
  FontColor->RGBColor[1, 0, 0]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.8470753285445232`*^9, 3.8470754816006403`*^9}, {
   3.84707551344792*^9, 3.847075600419808*^9}, {3.847075642240295*^9, 
   3.847075642560309*^9}, {3.847075709902536*^9, 3.847075741478705*^9}, {
   3.847075829625307*^9, 3.847075860858203*^9}, {3.847075906786566*^9, 
   3.847075962047545*^9}, {3.84707601280602*^9, 3.84707601584761*^9}, {
   3.847076062578526*^9, 3.847076071761094*^9}, {3.847076122531255*^9, 
   3.8470762108435793`*^9}, {3.847076331846223*^9, 3.847076374670672*^9}, {
   3.847076626768671*^9, 3.8470766611798487`*^9}, 3.847076716532598*^9, 
   3.847146990073325*^9, {3.847147034547307*^9, 
   3.847147036060796*^9}},ExpressionUUID->"df6c38c7-ff48-4ce2-bd2a-\
b6ef1d7ff38e"],

Cell[CellGroupData[{

Cell[BoxData["Profiti"], "Input",
 CellChangeTimes->{{3.847076254439657*^9, 3.847076256796652*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"dfa83e74-1850-484b-a5d9-b553004246b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8470762574365873`*^9, 3.8470765930685463`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"ba720b9d-5cbb-4868-bb25-53fb823f63bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[18]:=",ExpressionUUID->"068cd315-e88b-4caf-9afe-2c37a2602364"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"p", "+", 
     RowBox[{"2", " ", "k", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "r"}], ")"}]}], "-", 
     RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.847076597953541*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"ce8bb590-7049-4302-81ef-dbb2f7a761fd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"Profiti", "\[Equal]", "0"}], ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.847074840222671*^9, 3.847074843665584*^9}, {
  3.847075763854186*^9, 3.847075781197308*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"0d08a584-458c-487a-9aa6-adf9acfead12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["cs", "\[Alpha]"]}]}], "}"}], ",", 
   RowBox[{"{", 
    StyleBox[
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "k"}], "+", 
        RowBox[{"2", " ", "k", " ", "r"}], "+", "\[Theta]"}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}],
     FontColor->RGBColor[1, 0, 0]], "}"}]}], "}"}]], "Input",
 CellChangeTimes->{3.847076673776531*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"584adff7-0b8b-4680-976c-46789d397192"],

Cell[TextData[{
 "When the constraint is satisfied, the equilibrium premium rate for any \
given p becomes ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"\[Theta]", "  ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "p"}]}], 
      RowBox[{"2", "k"}]]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "c3b60caa-a940-41ab-a1f7-58b3c17a8013"]
}], "Text",
 CellChangeTimes->{{3.847076720758875*^9, 3.8470767380797777`*^9}, {
  3.847076780835041*^9, 
  3.847076840613296*^9}},ExpressionUUID->"9d20ba0f-069d-4ed5-b51b-\
78b2ca463adc"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"Profiti", "\[Equal]", "0"}], ",", "r"}], "]"}]], "Input",
 CellChangeTimes->{{3.84707674504283*^9, 3.847076754540276*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"55b617cd-63e1-4f7b-b320-4e72b0009257"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"r", "\[Rule]", 
    StyleBox[
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "k"}], "-", "p", "+", 
       RowBox[{"p", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]],
     FontColor->RGBColor[1, 0, 0]]}], "}"}], "}"}]], "Input",
 CellChangeTimes->{3.847076772354334*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"b8f3d753-e91f-4a6f-abec-5293e9b60604"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The SO\[CloseCurlyQuote]s Optimal Contract Under \
Insurance Model", "Section"]], "Subsubsection",
 CellChangeTimes->{{3.8470768941909723`*^9, 
  3.847076937239661*^9}},ExpressionUUID->"706f93f2-b69e-4203-b2f1-\
5693e30b390f"],

Cell[BoxData[
 StyleBox[
  RowBox[{"e", ":=", 
   FractionBox[
    RowBox[{"p", "-", 
     RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
    RowBox[{"2", " ", "k"}]]}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{{3.847093843483549*^9, 3.847093867718318*^9}, 
   3.847093960785281*^9, 3.847095946263722*^9, 3.847103387114477*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"ed13891d-91c1-4f8b-add5-c4c03e51702b"],

Cell[BoxData[
 RowBox[{"r", ":=", 
  StyleBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "k"}], "-", "p", "+", 
     RowBox[{"p", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
    RowBox[{"2", " ", "k"}]],
   FontColor->RGBColor[1, 0, 0]]}]], "Input",
 CellChangeTimes->{{3.847315863915306*^9, 3.847315871529646*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"2e0e85e1-ba57-408b-af2b-ca147140e783"],

Cell[BoxData[
 StyleBox[
  RowBox[{"Profits", ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], " ", "p"}], "+", 
    RowBox[{"e", 
     RowBox[{"(", 
      RowBox[{"f", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}]}], ")"}]}], "-", "cs", 
    " ", "-", 
    RowBox[{"r", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", "p"}], "+", "cs", "+", "f"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "e"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", "p"}], "+", "cs", "+", "f"}], ")"}]}]}]}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"0540a33a-601e-4372-8314-67141748de95"],

Cell[CellGroupData[{

Cell[BoxData["Profits"], "Input",
 CellChangeTimes->{{3.847333389700796*^9, 3.8473333913372173`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"4e3164f8-23e4-432a-aa59-6524b9a4a9d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cs"}], "-", 
  RowBox[{"p", " ", "\[Alpha]"}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", "f", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k"}], "-", "p", "+", 
      RowBox[{"p", " ", "\[Alpha]"}], "-", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"f", "-", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"cs", "+", "f", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.847333391934566*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"e228ee0c-d18e-4374-8e63-d2031f9efc13"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "-", 
   RowBox[{"p", " ", "\[Alpha]"}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cs", "+", "f", "+", 
       RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "k"}], "-", "p", "+", 
       RowBox[{"p", " ", "\[Alpha]"}], "-", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"f", "-", 
       RowBox[{"p", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", "f", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[6]:=",ExpressionUUID->"51eb0668-a7ff-46f5-ad6a-c571867d6f8b"],

Cell[BoxData[
 StyleBox[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "cs", " ", "k"}], "+", 
    RowBox[{"f", " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], "-", 
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"p", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "+", 
       RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", "\[Theta]", "-", 
       RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], ")"}]}]}], 
   RowBox[{"2", " ", "k"}]],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{3.847333693924368*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"1cfc7c9b-fc31-49fc-8414-c93dd3663125"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.847333402710328*^9, 3.8473334138429747`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"93e5e3bf-d7f1-4596-a84b-ed80eadb1b87"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"f", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"2", " ", "p", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "-", 
   RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
   RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.8473334146727123`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"183d6582-de72-4e14-a440-25815f513de1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"f", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "-", 
    RowBox[{"2", " ", "p", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "-", 
    RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
    RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], 
   RowBox[{"2", " ", "k"}]], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[8]:=",ExpressionUUID->"2b26d71b-4d60-4b8e-8571-0880b8ee4e27"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"f", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "+", 
    RowBox[{"2", " ", "p", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "+", 
    RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", "\[Theta]", "-", 
    RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.84733341852036*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"6b5132ba-1bc4-4479-8be4-92f96deee39d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.847333422072893*^9, 3.847333428974415*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"409779a0-43cd-4cae-b1c2-8a57f499a34e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"{", 
    StyleBox[
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       RowBox[{"f", "-", 
        RowBox[{"f", " ", "\[Alpha]"}], "-", 
        RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
        RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}]]}],
     FontColor->RGBColor[1, 0, 0]], "}"}], "}"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.8473334598761473`*^9, {3.8473353268252497`*^9, 
   3.8473353276242743`*^9}},ExpressionUUID->"6dab324f-f0fc-40ef-b7ad-\
2ba8bf7516fa"],

Cell[BoxData[
 RowBox[{"Profits", ":=", 
  RowBox[{"v", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", "p"}], "+", 
     RowBox[{"e", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "+", "cs"}], ")"}], " ", 
   "-", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}]}]}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"dfcd760f-e45d-47f0-8136-521e06595ffa"],

Cell[CellGroupData[{

Cell[BoxData["Profits"], "Input",
 CellChangeTimes->{{3.8473159008407927`*^9, 3.847315902363488*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"fd7d04c4-3db5-4827-9dc8-2aa739778d45"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cs"}], "+", "v", "-", 
  RowBox[{"p", " ", "\[Alpha]"}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k"}], "-", "p", "+", 
      RowBox[{"p", " ", "\[Alpha]"}], "-", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "-", 
  FractionBox[
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8473159029666367`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"947d94f9-7402-436c-9bde-cba05b41fc7a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "+", "v", "-", 
   RowBox[{"p", " ", "\[Alpha]"}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"cs", "+", 
       RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "k"}], "-", "p", "+", 
       RowBox[{"p", " ", "\[Alpha]"}], "-", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "-", 
   FractionBox[
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[5]:=",ExpressionUUID->"b22c0fbf-bd5d-4558-9595-7887e7d2468d"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", "cs", " ", "k"}], "-", 
    RowBox[{"2", " ", "k", " ", "v"}], "+", 
    RowBox[{
     SuperscriptBox["p", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "+", 
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", "\[Theta]", "-", 
       RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], ")"}]}]}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.8473159056038322`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"16fdfc69-54dc-4185-a319-2a2371905937"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.8473160505988483`*^9, 3.847316068509276*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"4c351107-c204-4dbd-960f-656ee241c8ac"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", "p", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}], "+", 
    RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", "\[Theta]", "-", 
    RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.847316070046681*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"304e1aa5-755c-4dba-94b9-eb07fe47d6d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.8473160737042713`*^9, 3.847316085084104*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"a3541540-25cd-4a8e-8644-8c5cb12ab3cb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "k", " ", "\[Alpha]"}], "-", "\[Theta]", "+", 
      
      RowBox[{"\[Alpha]", " ", "\[Theta]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.847316086411811*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"3877d4f5-0bf6-4330-842e-61662d0a1b9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Profits"], "Input",
 CellChangeTimes->{{3.847103393122921*^9, 3.847103399020447*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"ba015b43-54a5-4d0f-a28f-8156e75e06db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cs"}], "+", "v", "-", 
  RowBox[{"p", " ", "\[Alpha]"}], "-", 
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}]}], "-", 
  FractionBox[
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.847103400074251*^9, 3.847103428912465*^9}, 
   3.847149341825121*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"744ba428-58c0-419f-9ffb-46b8016e3f1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "+", "v", "-", 
   RowBox[{"p", " ", "\[Alpha]"}], "-", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[5]:=",ExpressionUUID->"ddbc7172-18d3-49fd-8fd8-e5c885d0436d"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", "k", " ", "v"}], "+", 
   RowBox[{
    SuperscriptBox["p", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"cs", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", 
      RowBox[{"2", " ", "k", " ", "r"}], "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], "-", 
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     ")"}]}]}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.8471493456151733`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"33dfa484-d337-4818-9845-741c201de423"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "+", "v", "-", 
   RowBox[{"p", " ", "\[Alpha]"}], "-", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[45]:=",ExpressionUUID->"e7b5481e-e699-4cc8-b7f9-54166060c781"],

Cell[CellGroupData[{

Cell[BoxData[{
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", "k", " ", "v"}], "+", 
   RowBox[{
    SuperscriptBox["p", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"cs", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", 
      RowBox[{"2", " ", "k", " ", "r"}], "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], "-", 
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     ")"}]}]}], 
  RowBox[{"2", " ", "k"}]], "\[IndentingNewLine]", 
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "p"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8471493888198757`*^9, 3.847149394552474*^9}, {
  3.8471494267544937`*^9, 3.847149426908002*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"f0d8b0ef-83c2-4bce-a9d2-c8cace4491e0"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", "k", " ", "v"}], "+", 
   RowBox[{
    SuperscriptBox["p", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"cs", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", 
      RowBox[{"2", " ", "k", " ", "r"}], "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], "-", 
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     ")"}]}]}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.8471493951740503`*^9, 3.847149427971352*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"aba04e4f-1901-4a6e-bdfd-d3868c9b997f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "cs"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "+", 
   RowBox[{"2", " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
  RowBox[{"2", " ", "k"}]], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", "p"}], "]"}]}], "Input",
 CellChangeTimes->{{3.847149432023081*^9, 3.8471494428146544`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"67a8b44b-f53e-476b-9920-f64883a6c6ed"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "cs"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "+", 
   RowBox[{"2", " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.847149443711831*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"d0ea7134-5db2-4b6c-b583-63cc8e7b4c5a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", "\[Rule]", 
    FractionBox[
     RowBox[{"cs", "-", 
      RowBox[{"cs", " ", "\[Alpha]"}], "+", 
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.847149443720381*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"f972186f-6e12-4743-97ba-901e89450607"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"e", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["\[Equal]",
     FontColor->RGBColor[1, 0, 0]], "0"}], 
   StyleBox[",",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["p",
    FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input",
 CellChangeTimes->{{3.847103504238941*^9, 3.847103543276004*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"c7c7c8cc-dfaa-4f9b-a125-6351e686a6f5"],

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "e", " ", "k"}], "+", "\[Theta]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}], "}"}], 
  "}"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"p", "-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "e", " ", "k"}], "+", "\[Theta]"}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}], "\[Equal]", "0"}], ",", 
   "e"}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.847105509728528*^9, 3.847105580039579*^9}, {
  3.847105799325019*^9, 3.847105841828084*^9}, {3.8471058861770353`*^9, 
  3.847105900918997*^9}, {3.847105948163906*^9, 3.847105949276263*^9}, {
  3.847106417412867*^9, 
  3.8471064486842613`*^9}},ExpressionUUID->"1eded644-6ad6-458d-8260-\
8c9516e8da48"],

Cell[CellGroupData[{

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.847106446793284*^9, 
  3.847106446796204*^9}},ExpressionUUID->"7066e856-68e1-479c-81dc-\
8e8990adafc4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    FractionBox[
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"2", " ", "k"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.847106442709633*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"3f847281-03af-4866-a109-4ef5f62052cf"],

Cell[BoxData[
 RowBox[{"P", "<", "v"}]], "Output",
 CellChangeTimes->{3.847106442715756*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"c573ac54-82e4-4bf1-8069-75e1bb7642bc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cs", "+", "cv", "+", 
     RowBox[{"k", "*", "e", "*", "e"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "e"}], ")"}], "\[Theta]"}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "e", " ", "k"}], "+", "\[Theta]"}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}], "\[Equal]", "0"}], ",", 
   "e"}], "]"}]], "Input",
 CellChangeTimes->{{3.8471059715025673`*^9, 3.847105998467668*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"9ff7d656-a76a-4ed6-9ee9-71355b6c08da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"e", "\[Rule]", 
     StyleBox[
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "k"}], 
         RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "-", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
          RowBox[{"4", " ", "cv", " ", "k"}], "+", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["k", "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
          RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
          SuperscriptBox["\[Theta]", "2"]}]]}], 
       RowBox[{"2", " ", "k"}]],
      FontColor->RGBColor[1, 0, 0]]}], 
    StyleBox["}",
     FontColor->RGBColor[1, 0, 0]]}], ",", 
   RowBox[{"{", 
    RowBox[{"e", "\[Rule]", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "k"}], 
        RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "+", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
         RowBox[{"4", " ", "cv", " ", "k"}], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["k", "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
         RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
         SuperscriptBox["\[Theta]", "2"]}]]}], 
      RowBox[{"2", " ", "k"}]]}], "}"}]}], "}"}]], "Input",
 CellChangeTimes->{3.847314583055575*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"e2d19a9b-89a1-4a2b-87c1-afa168ba33d1"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.847106044619875*^9, 
  3.847106086356336*^9}},ExpressionUUID->"ff0f2ff3-0866-4d98-b5eb-\
481bb689ff53"],

Cell[TextData[{
 "Proof of Proposition 1. We prove the results by using e as the decision \
variable (instead of p). In preparation, let us transform the constraints in \
terms of e (instead of p). \n\nFirst, by considering insurer acceptance \
constraint  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"p", ">", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "k"}], "+", 
      RowBox[{"2", " ", "k", " ", "r"}], "+", "\[Theta]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}],
   FontColor->RGBColor[1, 0, 0]]], "Input",
  CellChangeTimes->{3.847076673776531*^9},ExpressionUUID->
  "b2633f83-cce1-4d33-ad01-8d11181871e9"],
 "holds if and only if ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "k", " ", "e"}], " ", "-", " ", "\[Theta]"}], 
    RowBox[{"1", "-", "\[Alpha]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "06af102c-128d-4ced-9d2f-bad4677da27d"],
 " \[GreaterEqual] ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "k"}], "+", 
    RowBox[{"2", " ", "k", " ", "r"}], "+", "\[Theta]"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[Alpha]"}]]], "Input",
  CellChangeTimes->{3.847076673776531*^9},ExpressionUUID->
  "f578adc4-4d3e-42c9-b71b-87dbdf197639"],
 ",\nor, equivalently, ",
 StyleBox["e \[GreaterEqual] 1-r",
  FontColor->RGBColor[1, 0, 0]],
 "."
}], "Text",
 CellChangeTimes->{{3.847106964579541*^9, 3.847107049541449*^9}, {
  3.8471071100302896`*^9, 3.847107168699107*^9}, {3.847142970316187*^9, 
  3.8471429703164186`*^9}},ExpressionUUID->"72e9e011-97fd-48fc-8f55-\
07b42f72b920"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8471060821215067`*^9, 
  3.847106082419211*^9}},ExpressionUUID->"2c1624a5-4a21-4a2a-adca-\
de8275879afc"],

Cell[TextData[{
 "Second, we can apply ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"e", "=", 
    FractionBox[
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"2", " ", "k"}]]}],
   FontColor->RGBColor[1, 0, 0]]], "Input",
  CellChangeTimes->{{3.847093843483549*^9, 3.847093867718318*^9}, 
    3.847093960785281*^9, 3.847095946263722*^9, 3.847103387114477*^9},
  ExpressionUUID->"c67aaf48-c18e-41a7-b771-389f539bd6e8"],
 "  to express p in terms of e so that ",
 StyleBox["p =",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"2", "k", " ", "e"}], " ", "-", "\[Theta]"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "40200ee8-7c00-4210-a5ee-b752d6075eaf"],
 ". By using this expression of p, it is easy to check that the boundary \
constraint p \[LessEqual] v holds if and only if  ",
 StyleBox["e \[Element] ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    UnderscriptBox["e", "_"]}], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "55eed8e3-121a-4cd1-877a-7064a8d86361"],
 StyleBox[",  ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   OverscriptBox["e", "-"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "28bb8e4d-7403-4d3b-812e-163ac1208f2e"],
 StyleBox["\:0304]",
  FontColor->RGBColor[1, 0, 0]],
 ", where  ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["e", "_"], TraditionalForm]],ExpressionUUID->
  "c6b236a3-f76d-4ffe-9004-2b6863053d45"],
 " =",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "k"}], 
     RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "-", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
      RowBox[{"4", " ", "cv", " ", "k"}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["k", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
      RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
      SuperscriptBox["\[Theta]", "2"]}]]}], 
   RowBox[{"2", " ", "k"}]]], "Output",
  CellChangeTimes->{3.847106014227799*^9},
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "e20c3e37-dc8b-4430-b5a5-7d4964687770"],
 StyleBox[", \n",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   OverscriptBox["e", "-"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "f8155df1-a402-4065-8afe-ace93123b2c9"],
 StyleBox[" = ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FractionBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "k"}], 
     RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "+", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
      RowBox[{"4", " ", "cv", " ", "k"}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["k", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
      RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
      SuperscriptBox["\[Theta]", "2"]}]]}], 
   RowBox[{"2", " ", "k"}]]], "Output",
  CellChangeTimes->{3.847106014227799*^9},
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "62d5a41f-0560-4038-9989-a341f7cd118e"],
 "\nBy substituting ",
 StyleBox["p =",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"2", "ke"}], " ", "-", "\[Theta]"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "162b4241-7e37-4609-b40b-65dc2ed93848"],
 " into the satellite owner\[CloseCurlyQuote]s  payoff (9) along with the \
transformed constraints in terms of e, the satellite owner\[CloseCurlyQuote]s \
profit can be written as:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"max", " ", 
     SubscriptBox["\[CapitalPi]", "S"]}], "="}], TraditionalForm]],
  ExpressionUUID->"8102c0a6-445f-406d-9d40-8c8afe9a8dc4"],
 " v-(\[Alpha] p+e(1-\[Alpha])p+cs) -r(\[Alpha] p+cs)+(1-e)(\[Alpha] p+cs) = ",
 StyleBox["v-(e+r)cs +",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Theta]", " ", "-", " ", 
       RowBox[{"2", "k", " ", "e"}]}], " ", ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", "r"}], " ", "+", " ", "e"}], " ", ")"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "2325e164-defd-43a2-9a31-0838fdcbd97b"]
}], "Text",
 CellChangeTimes->{{3.8471037871588707`*^9, 3.847103791632761*^9}, {
   3.8471038219974833`*^9, 3.847103827134252*^9}, {3.847103858247069*^9, 
   3.847103883047966*^9}, {3.8471054033229437`*^9, 3.8471054749112577`*^9}, {
   3.847106193323133*^9, 3.8471062827007113`*^9}, {3.847107216092814*^9, 
   3.8471072233940372`*^9}, {3.847107256202464*^9, 3.847107290232917*^9}, {
   3.8471073607452517`*^9, 3.847107372486711*^9}, {3.8471074690034*^9, 
   3.847107653597186*^9}, {3.84710768699986*^9, 3.847107689249161*^9}, 
   3.847107744180401*^9, {3.8471083123792562`*^9, 3.84710839217581*^9}, 
   3.847140798913829*^9, {3.8471411306941977`*^9, 3.8471411525234613`*^9}, {
   3.847142996700457*^9, 3.847142996701085*^9}, 3.8471482191771708`*^9, {
   3.847264483632078*^9, 
   3.8472644879552307`*^9}},ExpressionUUID->"8eaa5472-7f35-4a5e-a58a-\
309c38629570"],

Cell[BoxData[
 RowBox[{"Profits", ":=", 
  RowBox[{"v", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", "p"}], "+", 
     RowBox[{"e", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "+", "cs"}], ")"}], " ", 
   "-", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.847107702786523*^9, 3.847107711142744*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"95632243-8672-419c-8852-afe6ea2be148"],

Cell[BoxData[
 RowBox[{"p", " ", ":=", 
  FormBox[
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"2", "k", " ", "e"}], " ", "-", "\[Theta]"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]],
   TraditionalForm]}]], "Input",
 CellChangeTimes->{{3.847107724747797*^9, 3.847107728888546*^9}, 
   3.847140729090605*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"50fdc178-364b-432a-8726-33ea5d0f578e"],

Cell[CellGroupData[{

Cell[BoxData["Profits"], "Input",
 CellChangeTimes->{{3.847107731730957*^9, 3.847107733917008*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"dd71c187-6900-4c21-8c6f-9d778c6d53be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cs"}], "+", "v", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "e"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     FractionBox[
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
      RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     FractionBox[
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
      RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], "-", 
  FractionBox[
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
   RowBox[{"1", "-", "\[Alpha]"}]]}]], "Output",
 CellChangeTimes->{3.8471077348329277`*^9, 3.847140737669306*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"828db34c-0dbf-4b19-a988-a7bb9c5a27a8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "+", "v", "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
   RowBox[{"e", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[6]:=",ExpressionUUID->"d21c10e1-c3fa-49db-99c3-2e37638d190f"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["e", "2"], " ", "k"}], "+", "v", "+", 
    RowBox[{"cs", " ", 
     RowBox[{"(", 
      RowBox[{"e", "+", "r"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
    RowBox[{"v", " ", "\[Alpha]"}], "+", 
    RowBox[{"r", " ", "\[Alpha]", " ", "\[Theta]"}], "+", 
    RowBox[{"e", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "k", " ", "r", " ", "\[Alpha]"}], "+", 
       "\[Theta]"}], ")"}]}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}]], "Output",
 CellChangeTimes->{3.847140745598075*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"8bb44bea-fc96-45dd-8042-a8f1e1676bc9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"D", "[", 
   RowBox[{"%", ",", "e"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.847108756118194*^9, 3.8471087632566643`*^9}, 
   3.8471407593116283`*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"149fa544-0da5-4d89-b6ca-faa636ed8e55"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", "e", " ", "k"}], "+", 
    RowBox[{"cs", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
    RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}]], "Output",
 CellChangeTimes->{3.847108763664856*^9, 3.8471407626218843`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"3a8baaf3-cbe4-49be-8b42-a26e5942ad45"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "e", " ", "k"}], "+", 
     RowBox[{"cs", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
     RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[8]:=",ExpressionUUID->"dd72ae13-e0c7-4388-b29b-e22c25b9e7dc"],

Cell[BoxData[
 FractionBox[
  RowBox[{"cs", "+", 
   RowBox[{"4", " ", "e", " ", "k"}], "-", 
   RowBox[{"cs", " ", "\[Alpha]"}], "+", 
   RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", "\[Alpha]"}]]], "Output",
 CellChangeTimes->{3.847140765519474*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"e3765de3-b884-4458-8a2a-f79b22c030c8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"cs", "+", 
       RowBox[{"4", " ", "e", " ", "k"}], "-", 
       RowBox[{"cs", " ", "\[Alpha]"}], "+", 
       RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
      
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}]], "\[Equal]", "0"}], ",", "e"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.847140657648736*^9, 3.847140712234851*^9}, {
  3.847140771448615*^9, 3.847140778466567*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"628adfbf-f9b8-44bd-a235-a586e7328efe"],

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "cs"}], "+", 
      RowBox[{"cs", " ", "\[Alpha]"}], "-", 
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"4", " ", "k"}]]}], "}"}], "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "cs"}], "+", 
        RowBox[{"cs", " ", "\[Alpha]"}], "-", 
        RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"4", " ", "k"}]], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "k"}], 
         RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
          RowBox[{"4", " ", "cv", " ", "k"}], "+", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["k", "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
          RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
          SuperscriptBox["\[Theta]", "2"]}]]}], 
       RowBox[{"2", " ", "k"}]]}], "\[Equal]", "0"}], ",", "r"}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.84714232242343*^9, 3.847142349857419*^9}, {
  3.847142389026972*^9, 3.847142389620902*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"f117505f-b94c-4b7f-a131-328a1b8526ed"],

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "cs"}], "+", 
      RowBox[{"cs", " ", "\[Alpha]"}], "-", 
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"4", " ", "k"}]]}], "}"}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"e", ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "cs"}], "+", 
    RowBox[{"cs", " ", "\[Alpha]"}], "-", 
    RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
   RowBox[{"4", " ", "k"}]]}], "\[IndentingNewLine]", 
 RowBox[{"p", " ", ":=", 
  FormBox[
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"2", "k", " ", "e"}], " ", "-", "\[Theta]"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]],
   TraditionalForm]}]}], "Input",
 CellChangeTimes->{{3.847142559612813*^9, 3.847142570748419*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"264adc28-d6cf-4a73-b4c1-34e996987200"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8471428038128138`*^9, 
  3.847142803817766*^9}},ExpressionUUID->"8ed8d714-3e33-4582-bc25-\
d1dd42753668"],

Cell[CellGroupData[{

Cell[BoxData["p"], "Input",
 CellChangeTimes->{3.847142579618987*^9},
 CellLabel->"In[18]:=",ExpressionUUID->"7714bcb3-cc13-4e7b-b66b-1e80866fffbd"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "\[Theta]"}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "cs"}], "+", 
      RowBox[{"cs", " ", "\[Alpha]"}], "-", 
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     ")"}]}]}], 
  RowBox[{"1", "-", "\[Alpha]"}]]], "Output",
 CellChangeTimes->{3.847142580292429*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"4dc9a7d1-f675-473c-a3bd-4cb73f6ad74c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "\[Theta]"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "cs"}], "+", 
       RowBox[{"cs", " ", "\[Alpha]"}], "-", 
       RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      ")"}]}]}], 
   RowBox[{"1", "-", "\[Alpha]"}]], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[19]:=",ExpressionUUID->"1d779cf9-4e6b-427f-934c-18c1b9066942"],

Cell[BoxData[
 FractionBox[
  RowBox[{"cs", "-", 
   RowBox[{"cs", " ", "\[Alpha]"}], "+", 
   RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.8471425835132236`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"b5058653-9df3-4240-983c-4d873a3be723"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"e", ":=", 
  FractionBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "k"}], 
     RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "-", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
      RowBox[{"4", " ", "cv", " ", "k"}], "+", 
      FractionBox[
       RowBox[{"4", " ", "k", "*", "k"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}]}]], "-", 
      RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
      RowBox[{"\[Theta]", "*", "\[Theta]"}]}]]}], 
   RowBox[{"2", " ", "k"}]]}]], "Input",
 CellChangeTimes->{{3.847137197670977*^9, 3.847137205398831*^9}, {
  3.847137304782349*^9, 3.8471373083810368`*^9}, {3.847137342224532*^9, 
  3.8471373563990726`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"cc9d013c-4273-45e7-8352-668ee8ba8bc3"],

Cell[BoxData[
 RowBox[{"cs", ":=", 
  StyleBox[
   RowBox[{"v", "+", 
    FractionBox[
     RowBox[{"\[Theta]", "*", "\[Theta]"}], 
     RowBox[{"4", " ", "k"}]], "-", "cv", "-", "\[Theta]"}],
   FontColor->RGBColor[1, 0, 0]]}]], "Input",
 CellChangeTimes->{{3.8471372196970167`*^9, 3.84713728062157*^9}, {
  3.8471373965364437`*^9, 3.847137399343329*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"af150f17-bc4e-4e19-828a-c40e238f7728"],

Cell[CellGroupData[{

Cell[BoxData["e"], "Input",
 CellChangeTimes->{3.8471372531540823`*^9},
 CellLabel->"In[9]:=",ExpressionUUID->"ab693bea-a996-404f-bd33-0b64cd6c55fb"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "k"}], 
    RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "-", 
   SqrtBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "cv", " ", "k"}], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["k", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
     RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
     SuperscriptBox["\[Theta]", "2"], "-", 
     RowBox[{"4", " ", "k", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "cv"}], "+", "v", "-", "\[Theta]", "+", 
        FractionBox[
         SuperscriptBox["\[Theta]", "2"], 
         RowBox[{"4", " ", "k"}]]}], ")"}]}]}]]}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.847137253769478*^9, 3.8471373218248997`*^9, 
  3.847137367181419*^9, 3.84713740723766*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"df996971-5bdf-44fb-9673-1340d2cdbdf8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  FractionBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "k"}], 
     RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "-", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "cv", " ", "k"}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["k", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
      RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
      SuperscriptBox["\[Theta]", "2"], "-", 
      RowBox[{"4", " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "cv"}], "+", "v", "-", "\[Theta]", "+", 
         FractionBox[
          SuperscriptBox["\[Theta]", "2"], 
          RowBox[{"4", " ", "k"}]]}], ")"}]}]}]]}], 
   RowBox[{"2", " ", "k"}]], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[10]:=",ExpressionUUID->"2775b162-9213-4689-b92e-527abe99203c"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"1", "-", "\[Alpha]"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"k", " ", 
        RowBox[{"(", 
         RowBox[{"k", "-", 
          RowBox[{"v", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]]]}], "+", 
    "\[Theta]"}], 
   RowBox[{"2", " ", "k"}]]}]], "Output",
 CellChangeTimes->{3.8471374107010403`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"4a085e60-2461-4a35-b78b-9b46854bf91b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Profits", ":=", 
  RowBox[{"v", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", "p"}], "+", 
     RowBox[{"e", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "+", "cs"}], ")"}], " ", 
   "-", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}]}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"ed708d3a-c433-48a7-a00a-62c333b3fa38"],

Cell[BoxData[
 RowBox[{"e", ":=", 
  FractionBox[
   RowBox[{"p", "-", 
    RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
   RowBox[{"2", " ", "k"}]]}]], "Input",
 CellChangeTimes->{{3.847143116320472*^9, 3.847143119295302*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"45402fd1-bb31-4119-a642-c1e0d6c4cc3f"],

Cell[CellGroupData[{

Cell[BoxData["Profits"], "Input",
 CellChangeTimes->{{3.847143122037059*^9, 3.8471431299051857`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"654d59fb-2d01-4cb5-9ed8-f5bc8727dc79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cs"}], "+", "v", "-", 
  RowBox[{"p", " ", "\[Alpha]"}], "-", 
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}]}], "-", 
  FractionBox[
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"p", "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
   RowBox[{"2", " ", "k"}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.847143130332157*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"d6979569-a40f-491c-97cb-d0a1e79311f8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "+", "v", "-", 
   RowBox[{"p", " ", "\[Alpha]"}], "-", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "-", 
       RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], 
    RowBox[{"2", " ", "k"}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      RowBox[{"p", " ", "\[Alpha]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"p", "-", 
        RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[4]:=",ExpressionUUID->"ae01d7f0-b4e9-4480-ae71-c23d403f3efa"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", "k", " ", "v"}], "+", 
   RowBox[{
    SuperscriptBox["p", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"cs", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", 
      RowBox[{"2", " ", "k", " ", "r"}], "-", 
      RowBox[{"p", " ", "\[Alpha]"}], "+", "\[Theta]"}], ")"}]}], "-", 
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     ")"}]}]}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.847143132513406*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"3b567c49-b218-4754-b7b8-aa7ce69b84a2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.8471431548373117`*^9, 3.847143160668324*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"4672a3e4-9c7d-4f0d-9f92-1dea4b45b74b"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "cs"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "+", 
   RowBox[{"2", " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
   RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
  RowBox[{"2", " ", "k"}]]], "Output",
 CellChangeTimes->{3.8471431631153107`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"27bfdb05-1a89-4cd7-9087-47f18b7bfbec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "cs"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "+", 
      RowBox[{"2", " ", "p", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "-", "\[Theta]"}], 
     RowBox[{"2", " ", "k"}]], "\[Equal]", "0"}], ",", "p"}], "]"}]], "Input",\

 CellChangeTimes->{{3.847143166856152*^9, 3.847143181625422*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"3aead148-2e6b-4cf1-ab6a-800c85a2c891"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"p", "\[Rule]", 
    FractionBox[
     RowBox[{"cs", "-", 
      RowBox[{"cs", " ", "\[Alpha]"}], "+", 
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}]]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.847143182550706*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"cf1ba0b9-916c-402f-b125-71b7fdfd003e"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.847144854593851*^9, 
  3.847148337122362*^9},ExpressionUUID->"862ef9bf-b4c2-46e1-8950-\
c63c75c3436a"],

Cell[BoxData[{
 RowBox[{"e", ":=", 
  FractionBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "k"}], 
     RowBox[{"1", "-", "\[Alpha]"}]], "+", "\[Theta]", "+", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
      RowBox[{"4", " ", "cv", " ", "k"}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["k", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
      RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
      SuperscriptBox["\[Theta]", "2"]}]]}], 
   RowBox[{"2", " ", "k"}]]}], "\[IndentingNewLine]", 
 RowBox[{"p", " ", ":=", 
  FormBox[
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"2", "k", " ", "e"}], " ", "-", "\[Theta]"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]],
   TraditionalForm]}]}], "Input",
 CellChangeTimes->{{3.847149896909609*^9, 3.847149902779614*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"447d8d6a-b49a-4b30-9a28-f109625d2fee"],

Cell[CellGroupData[{

Cell[BoxData["p"], "Input",
 CellChangeTimes->{3.847149917340424*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"ae36b0c5-51ab-4036-9a31-97248df6b0c8"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "k"}], 
    RowBox[{"1", "-", "\[Alpha]"}]], "+", 
   SqrtBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
     RowBox[{"4", " ", "cv", " ", "k"}], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["k", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
     RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
     SuperscriptBox["\[Theta]", "2"]}]]}], 
  RowBox[{"1", "-", "\[Alpha]"}]]], "Output",
 CellChangeTimes->{3.847149917949499*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"0bec30d1-b95f-4d1c-8242-1f46b5aa09f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  FractionBox[
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "k"}], 
     RowBox[{"1", "-", "\[Alpha]"}]], "+", 
    SqrtBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
      RowBox[{"4", " ", "cv", " ", "k"}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["k", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], "2"]], "-", 
      RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
      SuperscriptBox["\[Theta]", "2"]}]]}], 
   RowBox[{"1", "-", "\[Alpha]"}]], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[6]:=",ExpressionUUID->"bc1357d0-64c1-4785-b2cf-8dcbddb1614c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "k"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}], "+", 
   SqrtBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "cs", " ", "k"}], "-", 
     RowBox[{"4", " ", "cv", " ", "k"}], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["k", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], "2"]], "-", 
     RowBox[{"4", " ", "k", " ", "\[Theta]"}], "+", 
     SuperscriptBox["\[Theta]", "2"]}]]}], 
  RowBox[{"1", "-", "\[Alpha]"}]]], "Output",
 CellChangeTimes->{3.84714992190478*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"47db81aa-2c6b-4275-a068-d747d9965f2f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"p", " ", ":=", 
  FormBox[
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"2", "k", " ", "e"}], " ", "-", "\[Theta]"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]],
   TraditionalForm]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"a77645d1-de77-46b8-b6d9-9597e52c6278"],

Cell[BoxData[
 RowBox[{"Profits", ":=", 
  RowBox[{"v", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", "p"}], "+", 
     RowBox[{"e", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "+", "cs"}], ")"}], " ", 
   "-", 
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], "+", "cs"}], ")"}]}]}]}]], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"70da1100-bd9c-4eb9-9e86-c753a6df9293"],

Cell[CellGroupData[{

Cell[BoxData["Profits"], "Input",
 CellChangeTimes->{{3.847265575253981*^9, 3.84726557714573*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"8a0ed001-1c92-4d0d-9849-ed7b042bf731"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cs"}], "+", "v", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "e"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     FractionBox[
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
      RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{"cs", "+", 
     FractionBox[
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
      RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], "-", 
  FractionBox[
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
   RowBox[{"1", "-", "\[Alpha]"}]]}]], "Output",
 CellChangeTimes->{3.847265578620768*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"61bcdd1b-106f-403d-874f-bb3b7e26127b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cs"}], "+", "v", "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{"cs", "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", 
   RowBox[{"e", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "e", " ", "k"}], "-", "\[Theta]"}], ")"}]}], 
    RowBox[{"1", "-", "\[Alpha]"}]]}], "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[4]:=",ExpressionUUID->"0c6dbb47-88cd-4ade-8e36-4bcb66946060"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["e", "2"], " ", "k"}], "+", "v", "+", 
    RowBox[{"cs", " ", 
     RowBox[{"(", 
      RowBox[{"e", "+", "r"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
    RowBox[{"v", " ", "\[Alpha]"}], "+", 
    RowBox[{"r", " ", "\[Alpha]", " ", "\[Theta]"}], "+", 
    RowBox[{"e", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "k", " ", "r", " ", "\[Alpha]"}], "+", 
       "\[Theta]"}], ")"}]}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}]], "Output",
 CellChangeTimes->{3.847265581533689*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"9553e1d2-09f3-4fd5-a5e3-c71519f4fac8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "e"}], "]"}]], "Input",
 CellChangeTimes->{{3.8472656046466*^9, 3.847265609332079*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"e259b09f-f4b4-4654-92e0-c487b61f3400"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", "e", " ", "k"}], "+", 
    RowBox[{"cs", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
    RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[Alpha]"}]]}]], "Output",
 CellChangeTimes->{3.8472656099779053`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"6641199d-a34b-498a-9216-21ef75ec20f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", "e"}], "]"}]], "Input",
 CellChangeTimes->{{3.847265750994315*^9, 3.847265759777911*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"6f067cac-375e-4ff6-81d2-801d005f7363"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "cs"}], "+", 
      RowBox[{"cs", " ", "\[Alpha]"}], "-", 
      RowBox[{"2", " ", "k", " ", "r", " ", "\[Alpha]"}], "+", "\[Theta]"}], 
     RowBox[{"4", " ", "k"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.847265760618647*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"3c5ab323-1a5c-4783-ac54-15e4b1770b1b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.84731983649686*^9, 
  3.847319837058893*^9}},ExpressionUUID->"8419bbe0-7e17-417c-affe-\
e9cb269f5458"],

Cell["\:82e5\:8003\:8651\:536b\:661f\:63d0\:524d\:7b7e\:8ba2\:4e86\:6570\:636e\
\:552e\:5356\:5408\:540c\:ff0c\:6536\:76ca\:4e3aF", "Text",
 CellChangeTimes->{{3.847319877583129*^9, 
  3.847319905653475*^9}},ExpressionUUID->"a5020cc0-6923-424a-9529-\
9618441a658c"],

Cell[BoxData[
 RowBox[{"Profits", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[Alpha]"}], " ", "p"}], " ", "+", 
   RowBox[{"e", " ", "[", 
    RowBox[{"F", "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}]}], "]"}], "-", "cs", "-", 
   
   RowBox[{"r", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], " ", "+", "cs", "+", "F"}], " ", 
     ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", "p"}], " ", "+", "cs", "+", "F"}], " ", 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.847319910423168*^9, 3.847319987950534*^9}, 
   3.847320377202664*^9, {3.847322954723557*^9, 
   3.847322955135434*^9}},ExpressionUUID->"d169b5aa-267b-4501-a40f-\
b5b34971a747"],

Cell[BoxData[
 RowBox[{"e", ":=", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "+", "\[Theta]"}], 
   RowBox[{"2", "k"}]]}]], "Input",
 CellChangeTimes->{{3.8473204986838503`*^9, 3.8473205223883543`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"8c48b587-3552-4ce2-8c91-fd44d9d59e87"],

Cell[BoxData[
 RowBox[{"r", ":=", 
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "p"}], "+", "\[Theta]"}], 
    RowBox[{"2", " ", "k"}]]}]}]], "Input",
 CellChangeTimes->{{3.847320526792676*^9, 3.847320554555819*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"a0b9d978-b579-4512-8b64-d076daec1769"],

Cell[BoxData["Profitc"], "Input",
 CellChangeTimes->{{3.847320564695945*^9, 3.847320568449336*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"e49f5c85-d8c3-4ed9-9626-e6e7760afd33"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.847999574473694*^9, 3.847999575397587*^9}, 
   3.847999642458005*^9},ExpressionUUID->"9dd9f3c7-732f-4e1a-84bd-\
bcb6bdcf446c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"e", ":=", 
  FractionBox[
   RowBox[{"f", "+", "\[Theta]"}], 
   RowBox[{"2", " ", "k"}]]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"p", ":=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f", "+", "\[Theta]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"f", "-", "\[Theta]"}], ")"}]}], "+", 
     RowBox[{"4", "k", 
      RowBox[{"(", 
       RowBox[{"cv", "+", "\[Theta]"}], ")"}]}]}], 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"f", "+", "\[Theta]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}]}], "+", 
     RowBox[{"2", " ", "k", " ", "\[Alpha]"}]}]]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 RowBox[{"Profitv", ":=", 
  RowBox[{
   RowBox[{"\[Alpha]", " ", "p"}], "+", 
   RowBox[{"e", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], "p"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "e"}], ")"}], "\[Theta]"}], "-", 
   RowBox[{"k", "*", 
    RowBox[{"(", 
     RowBox[{"e", "*", "e"}], ")"}]}], "-", 
   "cv"}]}], "\[IndentingNewLine]", "Profitv"}], "Input",
 CellChangeTimes->{{3.847999633764526*^9, 3.847999650507338*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"0e334415-f374-4728-939c-ab68cf69fd20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "cv"}], "-", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"f", "+", "\[Theta]"}], ")"}], "2"], 
   RowBox[{"4", " ", "k"}]], "-", 
  RowBox[{"\[Theta]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"f", "+", "\[Theta]"}], 
      RowBox[{"2", " ", "k"}]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{"cv", "+", "\[Theta]"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"f", "-", "\[Theta]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"f", "+", "\[Theta]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{"cv", "+", "\[Theta]"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"f", "-", "\[Theta]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}], ")"}]}], 
   RowBox[{"2", " ", "k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.8479996533694267`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"f60a9b7c-39e8-4908-a777-de77364df80a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "cv"}], "-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"f", "+", "\[Theta]"}], ")"}], "2"], 
    RowBox[{"4", " ", "k"}]], "-", 
   RowBox[{"\[Theta]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"f", "+", "\[Theta]"}], 
       RowBox[{"2", " ", "k"}]]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "k", " ", 
        RowBox[{"(", 
         RowBox[{"cv", "+", "\[Theta]"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"f", "-", "\[Theta]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"f", "+", "\[Theta]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "k", " ", 
        RowBox[{"(", 
         RowBox[{"cv", "+", "\[Theta]"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"f", "-", "\[Theta]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", "k", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "k", " ", "\[Alpha]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"f", "+", "\[Theta]"}], ")"}]}]}], ")"}]}]]}], 
  "]"}]], "Input",
 NumberMarks->False,
 CellLabel->"In[5]:=",ExpressionUUID->"4d1e06be-b0cc-4df9-8ac9-3de24f57247a"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["f", "2"], "+", 
      RowBox[{"4", " ", "cv", " ", "k"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "k"}], "-", "\[Theta]"}], ")"}], " ", 
       "\[Theta]"}]}], ")"}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}]}], "-", 
      RowBox[{"k", " ", "\[Alpha]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[Theta]"}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.8479996610146847`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"e580cf72-44fe-479a-af44-7a93abd49b44"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{819, 803},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules->{"TryRealOnly" -> False},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) \
(2020\:5e743\:670813\:65e5)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"58a27417-2138-42cb-ba1e-bb3e60bf22f6"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 348, 7, 94, "Chapter",ExpressionUUID->"a39687ae-fc3b-4bb9-bd7f-6a1cce55c6bd"],
Cell[931, 31, 401, 8, 81, "Text",ExpressionUUID->"4a074443-24c5-409e-83aa-d5efd512c40f"],
Cell[1335, 41, 458, 13, 30, "Input",ExpressionUUID->"b97db057-3326-4570-b145-bf5f3b37db78"],
Cell[1796, 56, 411, 11, 30, "Input",ExpressionUUID->"79cfa81a-e7be-48c4-a2d1-ac54021f07e2"],
Cell[2210, 69, 284, 5, 30, "Input",ExpressionUUID->"53785147-afaf-421b-9557-079ea54a50de"],
Cell[2497, 76, 209, 5, 44, "Input",ExpressionUUID->"e5ce236c-099f-4fa3-baeb-556f27ae00e1"],
Cell[2709, 83, 275, 7, 30, "Input",ExpressionUUID->"36a6f063-e7cb-456b-a8fa-26f7686dc301"],
Cell[CellGroupData[{
Cell[3009, 94, 258, 5, 44, "Input",ExpressionUUID->"9535aaaa-7402-46ed-a57c-598d9755fb32"],
Cell[3270, 101, 279, 7, 49, "Output",ExpressionUUID->"e7dd1525-589b-464a-84dc-f91157728724"]
}, Open  ]],
Cell[3564, 111, 293, 7, 46, "Input",ExpressionUUID->"a6b4c8f3-f4b1-4542-b04d-0c61fa353d55"],
Cell[3860, 120, 178, 2, 30, "Input",ExpressionUUID->"3d692f04-76cd-4929-b634-5612de74c716"],
Cell[4041, 124, 472, 14, 30, "Input",ExpressionUUID->"a1c40ca2-1b2e-42b9-a8ad-ea757e0a057d"],
Cell[4516, 140, 456, 13, 63, "Input",ExpressionUUID->"6bfe07aa-d077-4fee-8be6-e182ce2d877c"],
Cell[4975, 155, 354, 9, 50, "Input",ExpressionUUID->"a0a114d9-6e19-44aa-8b58-739f998a2b1b"],
Cell[CellGroupData[{
Cell[5354, 168, 2878, 71, 217, "Section",ExpressionUUID->"fe88380d-793a-4f5f-b64c-83e0a6b818d6"],
Cell[CellGroupData[{
Cell[8257, 243, 930, 23, 88, "Subsection",ExpressionUUID->"6a672dce-496a-4be8-9aaa-aeac76186792"],
Cell[9190, 268, 122, 3, 20, "Outline5",ExpressionUUID->"faa6d505-3217-48b9-8ae3-0b4087d78c0a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9361, 277, 254, 4, 67, "Section",ExpressionUUID->"d1c34096-ed56-4bf5-8295-cf32091bad59"],
Cell[9618, 283, 1564, 43, 52, "Input",ExpressionUUID->"8a5e1f21-e832-4717-962f-486d55afa183"],
Cell[11185, 328, 487, 14, 30, "Input",ExpressionUUID->"8cbb3264-6d58-415e-92c3-60128108ea58"],
Cell[CellGroupData[{
Cell[11697, 346, 388, 9, 65, "Input",ExpressionUUID->"d31efafa-2322-4f06-9ec0-e5237b333828"],
Cell[12088, 357, 342, 8, 34, "Output",ExpressionUUID->"044ffb70-ef1f-4f88-9328-646880c8f795"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12467, 370, 368, 7, 65, "Input",ExpressionUUID->"de76a8b0-490e-424c-b61a-95614f7fe848"],
Cell[12838, 379, 373, 9, 49, "Output",ExpressionUUID->"67d1a863-98af-414a-861a-eb34be153095"]
}, Open  ]],
Cell[13226, 391, 353, 7, 58, "Text",ExpressionUUID->"451b9fe5-3c3d-4613-908c-73909ca7437c"],
Cell[13582, 400, 679, 18, 72, "Input",ExpressionUUID->"c1c41658-3282-4887-9481-14e609cd0c24"],
Cell[CellGroupData[{
Cell[14286, 422, 148, 2, 30, "Input",ExpressionUUID->"25cb81c3-86cf-4008-824c-618161218f24"],
Cell[14437, 426, 291, 7, 49, "Output",ExpressionUUID->"260ac273-416b-444b-a3de-a810a1416a8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14765, 438, 178, 2, 30, "Input",ExpressionUUID->"8be2c682-3e94-4521-ab90-197cf842636c"],
Cell[14946, 442, 525, 15, 51, "Output",ExpressionUUID->"db458e3f-3cc9-48d2-bc7d-8bae9c67660b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15508, 462, 550, 16, 61, "Input",ExpressionUUID->"cf5a4bec-fb6e-4eb0-a1a2-1252486ce01f"],
Cell[16061, 480, 550, 16, 51, "Output",ExpressionUUID->"ba5276aa-c895-415e-a3e2-47271b67f117"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16648, 501, 221, 4, 44, "Input",ExpressionUUID->"6543476a-4e42-4bfc-a9f1-07581f0ccaf9"],
Cell[16872, 507, 782, 24, 51, "Output",ExpressionUUID->"92dae79e-61cb-4485-8b70-00b47c02decf"]
}, Open  ]],
Cell[17669, 534, 257, 5, 44, "Input",ExpressionUUID->"55edf4ba-a82b-4d55-94a0-8ebbc3d8113a"],
Cell[17929, 541, 681, 19, 52, InheritFromParent,ExpressionUUID->"fa7a84f4-163d-4a38-81e7-8a1525d77575"],
Cell[18613, 562, 151, 3, 30, "Input",ExpressionUUID->"d95483e2-77aa-49c6-b85a-99d4c84674e9"],
Cell[CellGroupData[{
Cell[18789, 569, 227, 3, 30, "Input",ExpressionUUID->"434a0535-7d04-4d53-b2de-8417db3361f4"],
Cell[19019, 574, 890, 26, 53, "Output",ExpressionUUID->"b7776507-15f1-4b45-8d7c-33844b26640e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19946, 605, 906, 27, 63, "Input",ExpressionUUID->"840dcf7e-69db-43fc-9142-46360f97dd28"],
Cell[20855, 634, 775, 23, 53, "Output",ExpressionUUID->"6ae48cb6-a000-4427-8300-d7724c871c89"]
}, Open  ]],
Cell[21645, 660, 906, 27, 63, "Input",ExpressionUUID->"d773155c-a29b-47d0-9c22-dbcca16e2801"],
Cell[22554, 689, 260, 6, 35, "Text",ExpressionUUID->"50bc3183-f931-4469-a255-541f34284653"],
Cell[22817, 697, 839, 25, 50, "Input",ExpressionUUID->"203e64c2-90ab-4789-97d1-516b527fe727"],
Cell[CellGroupData[{
Cell[23681, 726, 306, 6, 44, "Input",ExpressionUUID->"f5e832c2-d924-4517-ad74-e1c0f8b68538"],
Cell[23990, 734, 1870, 48, 104, "Output",ExpressionUUID->"d65b8b64-cd53-4e89-a162-2a26260045a2"]
}, Open  ]],
Cell[25875, 785, 1179, 32, 82, "Text",ExpressionUUID->"7b31a7f5-7396-487c-a8c1-0ef980574010"],
Cell[CellGroupData[{
Cell[27079, 821, 681, 19, 65, "Input",ExpressionUUID->"13b830df-b732-4df8-9ecc-2b792bc2a1fc"],
Cell[27763, 842, 511, 14, 54, "Output",ExpressionUUID->"8fbe1c3a-7feb-4a3b-8935-b5d96f12b240"]
}, Open  ]],
Cell[28289, 859, 917, 23, 56, "Input",ExpressionUUID->"f4d7dc08-b6ac-4a78-a186-6c4093672237"],
Cell[CellGroupData[{
Cell[29231, 886, 1196, 31, 69, "Input",ExpressionUUID->"d1a517d1-0bad-45c2-aeda-646729bf54ce"],
Cell[30430, 919, 811, 23, 59, "Output",ExpressionUUID->"2ccf8f90-6e4e-477d-926d-cca2f48471b4"]
}, Open  ]],
Cell[31256, 945, 848, 27, 30, "Input",ExpressionUUID->"f71c8be6-7a63-4858-b653-06d891d01d27"],
Cell[32107, 974, 296, 8, 46, "Input",ExpressionUUID->"57593b88-81c6-46e4-b4f9-c03a1ec8ea14"],
Cell[CellGroupData[{
Cell[32428, 986, 221, 3, 30, "Input",ExpressionUUID->"3d95f9fb-810f-4df0-ac56-28b3fa5dd635"],
Cell[32652, 991, 595, 16, 53, "Output",ExpressionUUID->"baa3b0c0-9ec6-480b-a390-cdcfd7a12106"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33284, 1012, 600, 17, 63, "Input",ExpressionUUID->"89b5094a-178e-4af4-bee0-48b3228e2f43"],
Cell[33887, 1031, 560, 15, 53, "Output",ExpressionUUID->"f893fb4a-214c-4263-95fc-f0dc0fa053b3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34484, 1051, 333, 7, 44, "Input",ExpressionUUID->"2fd082ab-2f0d-4dc9-bf82-98ba63309865"],
Cell[34820, 1060, 2196, 63, 153, "Output",ExpressionUUID->"e12a2ad8-c5aa-4408-ba25-77f15a53b394"]
}, Open  ]],
Cell[37031, 1126, 231, 5, 26, "Input",ExpressionUUID->"51545df1-71d0-4c26-ab57-d1f4faa259d1"],
Cell[37265, 1133, 152, 3, 30, "Input",ExpressionUUID->"aca45777-0963-49b6-8d34-30b03810bbab"],
Cell[37420, 1138, 237, 4, 51, "Text",ExpressionUUID->"7f21e962-4957-4667-8436-535cdc0b692c"],
Cell[37660, 1144, 2681, 63, 185, "Text",ExpressionUUID->"df6c38c7-ff48-4ce2-bd2a-b6ef1d7ff38e"],
Cell[CellGroupData[{
Cell[40366, 1211, 178, 2, 30, "Input",ExpressionUUID->"dfa83e74-1850-484b-a5d9-b553004246b3"],
Cell[40547, 1215, 588, 17, 49, "Output",ExpressionUUID->"ba720b9d-5cbb-4868-bb25-53fb823f63bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41172, 1237, 589, 18, 59, "Input",ExpressionUUID->"068cd315-e88b-4caf-9afe-2c37a2602364"],
Cell[41764, 1257, 522, 15, 51, "Output",ExpressionUUID->"ce8bb590-7049-4302-81ef-dbb2f7a761fd"]
}, Open  ]],
Cell[42301, 1275, 312, 6, 44, "Input",ExpressionUUID->"0d08a584-458c-487a-9aa6-adf9acfead12"],
Cell[42616, 1283, 630, 19, 49, "Input",ExpressionUUID->"584adff7-0b8b-4680-976c-46789d397192"],
Cell[43249, 1304, 704, 20, 41, "Text",ExpressionUUID->"9d20ba0f-069d-4ed5-b51b-78b2ca463adc"],
Cell[43956, 1326, 262, 5, 44, "Input",ExpressionUUID->"55b617cd-63e1-4f7b-b320-4e72b0009257"],
Cell[44221, 1333, 441, 12, 48, "Input",ExpressionUUID->"b8f3d753-e91f-4a6f-abec-5293e9b60604"],
Cell[CellGroupData[{
Cell[44687, 1349, 250, 4, 56, "Subsubsection",ExpressionUUID->"706f93f2-b69e-4203-b2f1-5693e30b390f"],
Cell[44940, 1355, 431, 10, 46, "Input",ExpressionUUID->"ed13891d-91c1-4f8b-add5-c4c03e51702b"],
Cell[45374, 1367, 398, 10, 48, "Input",ExpressionUUID->"2e0e85e1-ba57-408b-af2b-ca147140e783"],
Cell[45775, 1379, 750, 24, 30, "Input",ExpressionUUID->"0540a33a-601e-4372-8314-67141748de95"],
Cell[CellGroupData[{
Cell[46550, 1407, 179, 2, 30, "Input",ExpressionUUID->"4e3164f8-23e4-432a-aa59-6524b9a4a9d1"],
Cell[46732, 1411, 1161, 36, 51, "Output",ExpressionUUID->"e228ee0c-d18e-4374-8e63-d2031f9efc13"]
}, Open  ]],
Cell[47908, 1450, 1207, 37, 101, "Input",ExpressionUUID->"51eb0668-a7ff-46f5-ad6a-c571867d6f8b"],
Cell[49118, 1489, 802, 23, 52, "Input",ExpressionUUID->"1cfc7c9b-fc31-49fc-8414-c93dd3663125"],
Cell[CellGroupData[{
Cell[49945, 1516, 223, 4, 44, "Input",ExpressionUUID->"93e5e3bf-d7f1-4596-a84b-ed80eadb1b87"],
Cell[50171, 1522, 557, 15, 53, "Output",ExpressionUUID->"183d6582-de72-4e14-a440-25815f513de1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50765, 1542, 580, 16, 63, "Input",ExpressionUUID->"2b26d71b-4d60-4b8e-8571-0880b8ee4e27"],
Cell[51348, 1560, 607, 17, 53, "Output",ExpressionUUID->"6b5132ba-1bc4-4479-8be4-92f96deee39d"]
}, Open  ]],
Cell[51970, 1580, 256, 5, 44, "Input",ExpressionUUID->"409779a0-43cd-4cae-b1c2-8a57f499a34e"],
Cell[52229, 1587, 887, 23, 223, "Input",ExpressionUUID->"6dab324f-f0fc-40ef-b7ad-2ba8bf7516fa"],
Cell[53119, 1612, 628, 20, 30, "Input",ExpressionUUID->"dfcd760f-e45d-47f0-8136-521e06595ffa"],
Cell[CellGroupData[{
Cell[53772, 1636, 179, 2, 30, "Input",ExpressionUUID->"fd7d04c4-3db5-4827-9dc8-2aa739778d45"],
Cell[53954, 1640, 1079, 33, 51, "Output",ExpressionUUID->"947d94f9-7402-436c-9bde-cba05b41fc7a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55070, 1678, 1120, 34, 101, "Input",ExpressionUUID->"b22c0fbf-bd5d-4558-9595-7887e7d2468d"],
Cell[56193, 1714, 674, 19, 53, "Output",ExpressionUUID->"16fdfc69-54dc-4185-a319-2a2371905937"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56904, 1738, 223, 4, 44, "Input",ExpressionUUID->"4c351107-c204-4dbd-960f-656ee241c8ac"],
Cell[57130, 1744, 490, 13, 53, "Output",ExpressionUUID->"304e1aa5-755c-4dba-94b9-eb07fe47d6d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57657, 1762, 258, 5, 44, "Input",ExpressionUUID->"a3541540-25cd-4a8e-8644-8c5cb12ab3cb"],
Cell[57918, 1769, 550, 17, 55, "Output",ExpressionUUID->"3877d4f5-0bf6-4330-842e-61662d0a1b9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58505, 1791, 177, 2, 30, "Input",ExpressionUUID->"ba015b43-54a5-4d0f-a28f-8156e75e06db"],
Cell[58685, 1795, 939, 28, 50, "Output",ExpressionUUID->"744ba428-58c0-419f-9ffb-46b8016e3f1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59661, 1828, 926, 28, 60, "Input",ExpressionUUID->"ddbc7172-18d3-49fd-8fd8-e5c885d0436d"],
Cell[60590, 1858, 716, 21, 53, "Output",ExpressionUUID->"33dfa484-d337-4818-9845-741c201de423"]
}, Open  ]],
Cell[61321, 1882, 927, 28, 60, "Input",ExpressionUUID->"e7b5481e-e699-4cc8-b7f9-54166060c781"],
Cell[CellGroupData[{
Cell[62273, 1914, 870, 24, 86, "Input",ExpressionUUID->"f0d8b0ef-83c2-4bce-a9d2-c8cace4491e0"],
Cell[63146, 1940, 738, 21, 53, "Output",ExpressionUUID->"aba04e4f-1901-4a6e-bdfd-d3868c9b997f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63921, 1966, 650, 17, 84, "Input",ExpressionUUID->"67a8b44b-f53e-476b-9920-f64883a6c6ed"],
Cell[64574, 1985, 510, 14, 51, "Output",ExpressionUUID->"d0ea7134-5db2-4b6c-b583-63cc8e7b4c5a"],
Cell[65087, 2001, 505, 14, 53, "Output",ExpressionUUID->"f972186f-6e12-4743-97ba-901e89450607"]
}, Open  ]],
Cell[65607, 2018, 612, 18, 59, "Input",ExpressionUUID->"c7c7c8cc-dfaa-4f9b-a125-6351e686a6f5"],
Cell[66222, 2038, 943, 27, 128, "Input",ExpressionUUID->"1eded644-6ad6-458d-8260-8c9516e8da48"],
Cell[CellGroupData[{
Cell[67190, 2069, 152, 3, 30, "Input",ExpressionUUID->"7066e856-68e1-479c-81dc-8e8990adafc4"],
Cell[67345, 2074, 350, 9, 49, "Output",ExpressionUUID->"3f847281-03af-4866-a109-4ef5f62052cf"],
Cell[67698, 2085, 171, 3, 34, "Output",ExpressionUUID->"c573ac54-82e4-4bf1-8069-75e1bb7642bc"]
}, Open  ]],
Cell[67884, 2091, 616, 17, 62, "Input",ExpressionUUID->"9ff7d656-a76a-4ed6-9ee9-71355b6c08da"],
Cell[68503, 2110, 1726, 50, 132, "Input",ExpressionUUID->"e2d19a9b-89a1-4a2b-87c1-afa168ba33d1"],
Cell[70232, 2162, 152, 3, 30, "Input",ExpressionUUID->"ff0f2ff3-0866-4d98-b5eb-481bb689ff53"],
Cell[70387, 2167, 1650, 46, 133, "Text",ExpressionUUID->"72e9e011-97fd-48fc-8f55-07b42f72b920"],
Cell[72040, 2215, 154, 3, 30, "Input",ExpressionUUID->"2c1624a5-4a21-4a2a-adca-de8275879afc"],
Cell[72197, 2220, 5564, 155, 243, "Text",ExpressionUUID->"8eaa5472-7f35-4a5e-a58a-309c38629570"],
Cell[77764, 2377, 694, 21, 30, "Input",ExpressionUUID->"95632243-8672-419c-8852-afe6ea2be148"],
Cell[78461, 2400, 401, 11, 49, "Input",ExpressionUUID->"50fdc178-364b-432a-8726-33ea5d0f578e"],
Cell[CellGroupData[{
Cell[78887, 2415, 177, 2, 30, "Input",ExpressionUUID->"dd71c187-6900-4c21-8c6f-9d778c6d53be"],
Cell[79067, 2419, 1133, 34, 52, "Output",ExpressionUUID->"828db34c-0dbf-4b19-a988-a7bb9c5a27a8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80237, 2458, 1153, 35, 62, "Input",ExpressionUUID->"d21c10e1-c3fa-49db-99c3-2e37638d190f"],
Cell[81393, 2495, 809, 24, 54, "Output",ExpressionUUID->"8bb44bea-fc96-45dd-8042-a8f1e1676bc9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82239, 2524, 288, 6, 65, "Input",ExpressionUUID->"149fa544-0da5-4d89-b6ca-faa636ed8e55"],
Cell[82530, 2532, 529, 14, 52, "Output",ExpressionUUID->"3a8baaf3-cbe4-49be-8b42-a26e5942ad45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83096, 2551, 529, 15, 62, "Input",ExpressionUUID->"dd72ae13-e0c7-4388-b29b-e22c25b9e7dc"],
Cell[83628, 2568, 395, 9, 52, "Output",ExpressionUUID->"e3765de3-b884-4458-8a2a-f79b22c030c8"]
}, Open  ]],
Cell[84038, 2580, 629, 16, 83, "Input",ExpressionUUID->"628adfbf-f9b8-44bd-a235-a586e7328efe"],
Cell[84670, 2598, 1659, 44, 214, "Input",ExpressionUUID->"f117505f-b94c-4b7f-a131-328a1b8526ed"],
Cell[86332, 2644, 948, 26, 129, "Input",ExpressionUUID->"264adc28-d6cf-4a73-b4c1-34e996987200"],
Cell[87283, 2672, 154, 3, 30, "Input",ExpressionUUID->"8ed8d714-3e33-4582-bc25-d1dd42753668"],
Cell[CellGroupData[{
Cell[87462, 2679, 148, 2, 30, "Input",ExpressionUUID->"7714bcb3-cc13-4e7b-b66b-1e80866fffbd"],
Cell[87613, 2683, 491, 14, 58, "Output",ExpressionUUID->"4dc9a7d1-f675-473c-a3bd-4cb73f6ad74c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88141, 2702, 515, 15, 68, "Input",ExpressionUUID->"1d779cf9-4e6b-427f-934c-18c1b9066942"],
Cell[88659, 2719, 405, 10, 53, "Output",ExpressionUUID->"b5058653-9df3-4240-983c-4d873a3be723"]
}, Open  ]],
Cell[89079, 2732, 941, 25, 63, "Input",ExpressionUUID->"cc9d013c-4273-45e7-8352-668ee8ba8bc3"],
Cell[90023, 2759, 434, 10, 46, "Input",ExpressionUUID->"af150f17-bc4e-4e19-828a-c40e238f7728"],
Cell[CellGroupData[{
Cell[90482, 2773, 149, 2, 30, "Input",ExpressionUUID->"ab693bea-a996-404f-bd33-0b64cd6c55fb"],
Cell[90634, 2777, 994, 28, 67, "Output",ExpressionUUID->"df996971-5bdf-44fb-9673-1340d2cdbdf8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91665, 2810, 962, 28, 80, "Input",ExpressionUUID->"2775b162-9213-4689-b92e-527abe99203c"],
Cell[92630, 2840, 768, 25, 77, "Output",ExpressionUUID->"4a085e60-2461-4a35-b78b-9b46854bf91b"]
}, Open  ]],
Cell[93413, 2868, 628, 20, 30, "Input",ExpressionUUID->"ed708d3a-c433-48a7-a00a-62c333b3fa38"],
Cell[94044, 2890, 312, 7, 46, "Input",ExpressionUUID->"45402fd1-bb31-4119-a642-c1e0d6c4cc3f"],
Cell[CellGroupData[{
Cell[94381, 2901, 179, 2, 30, "Input",ExpressionUUID->"654d59fb-2d01-4cb5-9ed8-f5bc8727dc79"],
Cell[94563, 2905, 889, 27, 50, "Output",ExpressionUUID->"d6979569-a40f-491c-97cb-d0a1e79311f8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95489, 2937, 926, 28, 60, "Input",ExpressionUUID->"ae01d7f0-b4e9-4480-ae71-c23d403f3efa"],
Cell[96418, 2967, 714, 21, 53, "Output",ExpressionUUID->"3b567c49-b218-4754-b7b8-aa7ce69b84a2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97169, 2993, 223, 4, 44, "Input",ExpressionUUID->"4672a3e4-9c7d-4f0d-9f92-1dea4b45b74b"],
Cell[97395, 2999, 511, 14, 51, "Output",ExpressionUUID->"27bfdb05-1a89-4cd7-9087-47f18b7bfbec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97943, 3018, 655, 18, 61, "Input",ExpressionUUID->"3aead148-2e6b-4cf1-ab6a-800c85a2c891"],
Cell[98601, 3038, 504, 14, 53, "Output",ExpressionUUID->"cf1ba0b9-916c-402f-b125-71b7fdfd003e"]
}, Open  ]],
Cell[99120, 3055, 150, 3, 30, "Input",ExpressionUUID->"862ef9bf-b4c2-46e1-8950-c63c75c3436a"],
Cell[99273, 3060, 1022, 30, 111, "Input",ExpressionUUID->"447d8d6a-b49a-4b30-9a28-f109625d2fee"],
Cell[CellGroupData[{
Cell[100320, 3094, 147, 2, 30, "Input",ExpressionUUID->"ae36b0c5-51ab-4036-9a31-97248df6b0c8"],
Cell[100470, 3098, 713, 21, 68, "Output",ExpressionUUID->"0bec30d1-b95f-4d1c-8242-1f46b5aa09f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101220, 3124, 744, 22, 81, "Input",ExpressionUUID->"bc1357d0-64c1-4785-b2cf-8dcbddb1614c"],
Cell[101967, 3148, 781, 24, 68, "Output",ExpressionUUID->"47db81aa-2c6b-4275-a068-d747d9965f2f"]
}, Open  ]],
Cell[102763, 3175, 309, 9, 49, "Input",ExpressionUUID->"a77645d1-de77-46b8-b6d9-9597e52c6278"],
Cell[103075, 3186, 628, 20, 30, "Input",ExpressionUUID->"70da1100-bd9c-4eb9-9e86-c753a6df9293"],
Cell[CellGroupData[{
Cell[103728, 3210, 176, 2, 30, "Input",ExpressionUUID->"8a0ed001-1c92-4d0d-9849-ed7b042bf731"],
Cell[103907, 3214, 1109, 34, 52, "Output",ExpressionUUID->"61bcdd1b-106f-403d-874f-bb3b7e26127b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105053, 3253, 1153, 35, 62, "Input",ExpressionUUID->"0c6dbb47-88cd-4ade-8e36-4bcb66946060"],
Cell[106209, 3290, 809, 24, 54, "Output",ExpressionUUID->"9553e1d2-09f3-4fd5-a5e3-c71519f4fac8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107055, 3319, 219, 4, 44, "Input",ExpressionUUID->"e259b09f-f4b4-4654-92e0-c487b61f3400"],
Cell[107277, 3325, 507, 14, 52, "Output",ExpressionUUID->"6641199d-a34b-498a-9216-21ef75ec20f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107821, 3344, 256, 5, 44, "Input",ExpressionUUID->"6f067cac-375e-4ff6-81d2-801d005f7363"],
Cell[108080, 3351, 437, 11, 51, "Output",ExpressionUUID->"3c5ab323-1a5c-4783-ac54-15e4b1770b1b"]
}, Open  ]],
Cell[108532, 3365, 303, 6, 157, "Input",ExpressionUUID->"8419bbe0-7e17-417c-affe-e9cb269f5458"],
Cell[108838, 3373, 265, 4, 35, "Text",ExpressionUUID->"a5020cc0-6923-424a-9529-9618441a658c"],
Cell[109106, 3379, 824, 26, 30, "Input",ExpressionUUID->"d169b5aa-267b-4501-a40f-b5b34971a747"],
Cell[109933, 3407, 349, 9, 47, "Input",ExpressionUUID->"8c48b587-3552-4ce2-8c91-fd44d9d59e87"],
Cell[110285, 3418, 385, 10, 47, "Input",ExpressionUUID->"a0b9d978-b579-4512-8b64-d076daec1769"],
Cell[110673, 3430, 178, 2, 30, "Input",ExpressionUUID->"e49f5c85-d8c3-4ed9-9626-e6e7760afd33"],
Cell[110854, 3434, 229, 4, 73, "Input",ExpressionUUID->"9dd9f3c7-732f-4e1a-84bd-bcb6bdcf446c"],
Cell[CellGroupData[{
Cell[111108, 3442, 1291, 39, 134, "Input",ExpressionUUID->"0e334415-f374-4728-939c-ab68cf69fd20"],
Cell[112402, 3483, 1867, 59, 97, "Output",ExpressionUUID->"f60a9b7c-39e8-4908-a777-de77364df80a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114306, 3547, 1937, 61, 110, "Input",ExpressionUUID->"4d1e06be-b0cc-4df9-8ac9-3de24f57247a"],
Cell[116246, 3610, 846, 27, 56, "Output",ExpressionUUID->"e580cf72-44fe-479a-af44-7a93abd49b44"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

